from django.db import models
from django.utils.functional import cached_property
from django.conf import settings
from wagtail.admin.edit_handlers import MultiFieldPanel, StreamFieldPanel, PageChooserPanel
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtail.snippets.edit_handlers import SnippetChooserPanel
from wagtail.core.fields import StreamField
from wagtail.core.models import Page
from wagtail.admin.edit_handlers import FieldPanel, InlinePanel
from wagtail.core.utils import camelcase_to_underscore
from modelcluster.fields import ParentalKey
from wagtail.core.models import Orderable, Site

from webspace.bakery.models import VersionBuild
from webspace.cms.amp.mixins import AmpMixin
from webspace.cms.amp.utils import amp_mode_active
from webspace.cms import constants
from webspace.cms.blocks.schemas import HowTo, FAQPage
from webspace.loader import get_model, get_class

#  Classes

ArticlesEntry = get_class('cms.blocks.entries', 'ArticlesEntry')
ButtonsEntry = get_class('cms.blocks.entries', 'ButtonsEntry')
CardsEntry = get_class('cms.blocks.entries', 'CardsEntry')
EmbedEntry = get_class('cms.blocks.entries', 'EmbedEntry')
GridInfoEntry = get_class('cms.blocks.entries', 'GridInfoEntry')
ImageEntry = get_class('cms.blocks.entries', 'ImageEntry')
ComponentTextEntry = get_class('cms.blocks.entries', 'ComponentTextEntry')
MediasLineEntry = get_class('cms.blocks.entries', 'MediasLineEntry')
SvgEntry = get_class('cms.blocks.entries', 'SvgEntry')
TextEntry = get_class('cms.blocks.entries', 'TextEntry')
TimeLineEntry = get_class('cms.blocks.entries', 'TimeLineEntry')
CalendlyEntry = get_class('cms.blocks.entries', 'CalendlyEntry')
TableEntry = get_class('cms.blocks.entries', 'TableEntry')
NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
FormEntry = get_class('cms.blocks.entries', 'FormEntry')
PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')
GallerySliderEntry = get_class('cms.blocks.entries', 'GallerySliderEntry')



SocialShare = get_class('cms.blocks.static', 'SocialShare')
SocialLinks = get_class('cms.blocks.static', 'SocialLinks')

#  Models
Menu = get_model('cms', 'Menu')
IconSnippet = get_model('cms', 'IconSnippet')
Navigation = get_model('cms', 'Navigation')


class AMultiLanguagePage(Orderable):
    parent = ParentalKey('GenericPage', related_name='language_pages')
    language = models.CharField(
        choices=constants.LANGUAGES,
        default='',
        blank=True,
        max_length=100,
        help_text="Language de la page"
    )
    page = models.ForeignKey(
        Page,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Page",
    )

    panels = [
        FieldPanel("language"),
        PageChooserPanel("page"),
    ]

    class Meta:
        app_label = 'cms'
        abstract = True


class AGenericPage(Page):
    feed_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="SEO - Image",
    )

    theme = models.CharField(
        choices=constants.THEME_CHOICES,
        default=constants.THEME_SPACE,
        max_length=100,
        help_text="Permet de changer le theme du header et du footer"
    )

    breadcrumb = models.BooleanField(
        default=True,
        verbose_name="Public pour Google",
        help_text="Ajoute la page dans le sitemap et génère un schéma Breadcrumb",
    )

    schemas = StreamField([
        ('how_to', HowTo()),
        ('faq_page', FAQPage()),
    ], blank=True)

    navigation = models.ForeignKey(
        Navigation,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Navigation",
    )

    amp_active = models.BooleanField(default=True)

    body = StreamField([
        ('svg', SvgEntry()),
        ('image', ImageEntry()),
        ('text', TextEntry()),
        ('cards', CardsEntry()),
        ('component_text', ComponentTextEntry()),
        ('grid_info', GridInfoEntry()),
        ('medias_line', MediasLineEntry()),
        ('timeline', TimeLineEntry()),
        ('buttons', ButtonsEntry()),
        ('calendly', CalendlyEntry()),
        ('articles', ArticlesEntry()),
        ('embed', EmbedEntry()),
        ('social_share', SocialShare()),
        ('social_links', SocialLinks()),
        ('table', TableEntry()),
        ('accordion', AccordionEntry()),
        ('numbers', NumbersEntry()),
        ('form', FormEntry()),
        ('portfolios', PortfoliosEntry()),
        ('gallery', GalleryEntry()),
        ('gallery_slider', GallerySliderEntry()),
        ('stream_content', StreamContentEntry()),
    ], blank=True)

    content_panels = [
        StreamFieldPanel('body'),
    ]

    promote_panels = [
        MultiFieldPanel([
            FieldPanel('seo_title'),
            FieldPanel('search_description'),
        ], "Google Search"),
        MultiFieldPanel([
            ImageChooserPanel('feed_image'),
            FieldPanel('breadcrumb'),
        ], "SEO - DATA"),
    ]

    settings_panels = [
        FieldPanel('title'),
        FieldPanel('slug'),
        FieldPanel('theme'),
        FieldPanel('amp_active'),
        SnippetChooserPanel('navigation'),
        InlinePanel("language_pages", label="Pages multi-language")
    ]

    subpage_types = [
        'cms.ContentPage',
        'cms.DocumentPage',
        'cms.BlogPage',
    ]

    class Meta:
        abstract = True
        app_label = 'cms'

    def get_context(self, request, *args, **kwargs):
        context = super(AGenericPage, self).get_context(request)
        context['debug'] = settings.DEBUG
        context['icons'] = IconSnippet.get_context()
        context['version'] = VersionBuild.get().version
        context['site'] = Site.find_for_request(request)
        context['studio'] = {
            'name': constants.STUDIO_NAME,
            'email': constants.STUDIO_EMAIL,
            'url': constants.STUDIO_URL,
        }
        return context

    @cached_property
    def get_breadcrumbs(self):
        #  FIXME: filter by `breadcrumb` seem not to be possible with wagtail Page
        ret = []
        items = self.get_children().type(AGenericPage).specific().live()
        for item in items:
            if item.breadcrumb:
                ret.append(item)
        return ret

    def get_sitemap_urls(self, request=None):
        if not self.breadcrumb:
            return []
        urls = super().get_sitemap_urls(request)
        if self.language_pages:
            urls[-1]['alternatives'] = []
            for language_page in self.language_pages.all():
                urls[-1]['alternatives'].append({
                    'language': language_page.language,
                    'href': language_page.page.get_full_url(),
                })
        return urls

    def get_url_parts(self, *args, **kwargs):
        urls = super().get_url_parts(*args, **kwargs)
        if isinstance(self, AmpMixin) and amp_mode_active():
            return (urls[0], urls[1], '/amp' + urls[2])
        return urls

    def get_template(self, request, *args, **kwargs):
        return "%s/%s.html" % (
            constants.PAGES_TEMPLATES_PATH,
            camelcase_to_underscore(self.__class__.__name__)
        )



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    EntryBlock


class ClassicAccordionItem(blocks.StructBlock):
    head = TextBlock(label="Head")
    content = TextBlock(label="Head")


class AccordionEntry(EntryBlock):
    amp_scripts = ['accordion']
    items = blocks.StreamBlock([
        ('classic', ClassicAccordionItem()),
    ], min_num=1)

    def mock(self, *args, **kwargs):
        classic = {
            'type': 'classic',
            'value': {
                'head': {'value': self.p},
                'content': {'value': self.p},
            }
        }

        self.mock_data.update({
            'type': 'accordion',
            'value': {
                'items': [classic, classic, classic, classic]
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/accordion.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Accordion"



# Generated by Django 3.0.9 on 2020-08-25 15:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0020_auto_20200825_1734'),
    ]

    operations = [
        migrations.RenameField(
            model_name='webspacesettings',
            old_name='secondary_color',
            new_name='secondary_bg_color',
        ),
    ]



from .models import User
from django.contrib.auth.models import Group


def get_test_account():
    user, created = User.objects.get_or_create(
        username='test',
        first_name='Elon',
        last_name='Musk',
        email='test@test.test',
        is_staff=True,
        is_superuser=True,
        is_active=True
    )
    if created:
        user.save()
        user.set_password('azer')
        for group in Group.objects.all():
            user.groups.add(group)
        user.save()
    return user



from django.contrib import admin

from .models import TaskBuild, VersionBuild


class TaskBuildAdmin(admin.ModelAdmin):
    search_fields = ('task_id',)
    list_display = ('task_id', 'ready', 'date_start', 'date_end')


admin.site.register(TaskBuild, TaskBuildAdmin)
admin.site.register(VersionBuild)



from django.http import Http404
from wagtail.core.url_routing import RouteResult
from taggit.models import Tag
from webspace.loader import get_model


class TagMixin(object):
    #  Child must have tags and date and subpage_types

    def route(self, request, path_components):
        if path_components:
            if path_components[0] == 'tags':
                tag_slug = path_components[1]
                try:
                    tag = Tag.objects.get(slug__iexact=tag_slug)
                except Tag.DoesNotExist:
                    raise Http404
                if self.live:
                    return RouteResult(self, kwargs={"tag": tag})
                raise Http404
            else:
                path_components[0] = path_components[0]
        return super().route(request, path_components)

    @property
    def items(self):
        model_child = get_model('cms', self.subpage_types[0])
        return model_child.objects.live().descendant_of(self).order_by('-date')

    def get_context(self, request, tag=None):
        context = super().get_context(request)
        if tag:
            context['items'] = []
        else:
            context['items'] = self.items
        context['tags'] = []
        for child in self.get_children().live().specific():
            for tag_obj in child.tags.all():
                if tag_obj.name:
                    context['tags'].append(tag_obj)
                if tag and tag_obj.slug == tag.slug:
                    context['items'].append(child)

        context['tags'] = list(dict.fromkeys(context['tags']))
        if tag:
            context['items'] = list(dict.fromkeys(context['items']))

        context['current_tag'] = tag
        return context

    def serve(self, request, *args, **kwargs):
        if 'tag' not in kwargs:
            return super().serve(request)
        else:
            return super().serve(
                request,
                extra_path_file='tags/' + kwargs['tag'].slug + '/',
                *args,
                **kwargs
            )



# Generated by Django 3.0.7 on 2020-07-29 09:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20200728_1712'),
    ]

    operations = [
        migrations.AddField(
            model_name='portfoliopage',
            name='intro_title',
            field=models.CharField(blank=True, default='', help_text="Titre d'introduction qui s'affiche sur un block portfolio de présentation", max_length=500),
        ),
    ]



from wagtail.core import blocks
from wagtail.images.models import Image
from webspace.cms import constants
from webspace.cms.blocks.common import ImageWithSizeBlock, EntryBlock


class ImageEntry(EntryBlock):
    image = ImageWithSizeBlock()

    def mock(self, force_file=None, size='m', *args, **kwargs):
        if 'theme' in kwargs:
            img = self.IMG_CONTENT_WIDTH_LIGHT if kwargs['theme'] == constants.THEME_LIGHT else self.IMG_CONTENT_WIDTH_SPACE
        else:
            img = self.IMG_CONTENT_HEIGHT_SPACE
        self.mock_data.update({
            'type': 'image',
            'value': {
                'image': {
                    'file': self.file(img if not force_file else force_file).id,
                    'size': size
                }
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/image.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Image"
        icon = 'image'



import requests
import json
from datetime import datetime
from django.conf import settings
from wagtail.core.models import Site

import logging
from wagtail.core import blocks
from webspace.cms import constants

logger = logging.getLogger('email')


class SendGrid(object):

    @staticmethod
    def send_email_data(receiver_email, data, hostname):
        now = datetime.now()
        res = requests.post(
            "https://api.sendgrid.com/v3/mail/send",
            data=json.dumps({
                "from": {
                    "email": constants.STUDIO_EMAIL,
                    "name": "Notification %s" % constants.STUDIO_NAME
                },
                "personalizations": [
                    {
                        "to": [{"email": receiver_email}],
                        "custom_args": data,
                        "send_at": int(datetime.timestamp(now)),
                        "dynamic_template_data": {
                            "subject": "Notification %s" % hostname,
                            "data": data
                        }
                    }
                ],
                "template_id": "d-8cbd3714e87f4075a193b4c8fc0c8c78"
            }),
            headers={
                "Authorization": "Bearer " + settings.SENDGRID_SK,
                "Content-Type": "application/json",
            }
        )
        if res.status_code >= 400:
            logger.error('Email not send')
            logger.error(str(res.content))
        else:
            logger.debug('Email send')


class EmailActionValue(blocks.StructValue):
    def run(self, request, form_instance, form_data):
        email_receiver = self.get('email_receiver')
        site = Site.find_for_request(request)

        SendGrid.send_email_data(
            email_receiver,
            {'data': form_data},
            site.hostname
        )


class EmailAction(blocks.StructBlock):
    email_receiver = blocks.CharBlock(required=False)

    class Meta:
        value_class = EmailActionValue



STUDIO_NAME = 'Snoweb'
STUDIO_URL = 'https://www.snoweb.fr/'
STUDIO_EMAIL = "hello@snoweb.com"

BLOCK_TEMPLATES_PATH = 'cms/blocks'
PAGES_TEMPLATES_PATH = 'cms/pages'
ADMIN_TEMPLATES_PATH = 'cms/admin'

THEME_SPACE = 'space'
THEME_SPACE_INVERSE = 'space-inverse'
THEME_LIGHT = 'light'
THEME_LIGHT_INVERSE = 'light-inverse'

THEME_CHOICES = (
    (THEME_SPACE, "Primary"),
    (THEME_SPACE_INVERSE, "Primary Inverse"),
    (THEME_LIGHT, "Secondary"),
)

SIZE_XS = 'xs'
SIZE_S = 's'
SIZE_M = 'm'
SIZE_L = 'l'
SIZE_X = 'x'
SIZE_XL = 'xl'
SIZE_FULL = 'full'

SIZE_CHOICES = (
    (SIZE_XS, 'XS'),
    (SIZE_S, 'S'),
    (SIZE_M, 'M'),
    (SIZE_L, 'L'),
    (SIZE_X, 'X'),
    (SIZE_XL, 'XL'),
    (SIZE_FULL, 'Full'),
)

CONTAINER_REGULAR = 'regular'
CONTAINER_CONTENT = 'content'
CONTAINER_FULL = 'full'

CONTAINER_CHOICES = (
    (CONTAINER_REGULAR, 'Regular'),
    (CONTAINER_CONTENT, 'Content (blog)'),
    (CONTAINER_FULL, 'Full (width 100%)'),
)

BUTTON_PRIMARY = 'primary-light'
BUTTON_PRIMARY_FULL = 'primary-full'
BUTTON_SECONDARY = 'secondary-light'
BUTTON_SECONDARY_FULL = 'secondary-full'
BUTTON_TERTIARY = 'tertiary-light'
BUTTON_TERTIARY_FULL = 'tertiary-full'

BUTTON_CHOICES = (
    (BUTTON_PRIMARY, 'Primary Light'),
    (BUTTON_PRIMARY_FULL, 'Primary Full'),
    (BUTTON_SECONDARY, 'Secondary Light'),
    (BUTTON_SECONDARY_FULL, 'Secondary Full'),
    (BUTTON_TERTIARY, 'Tertiary Light'),
    (BUTTON_TERTIARY_FULL, 'Tertiary Full'),
)

ALIGN_TEXT_NULL = None
ALIGN_TEXT_LEFT = 'left'
ALIGN_TEXT_JUSTIFY = 'justify'
ALIGN_TEXT_CENTER = 'center'
ALIGN_TEXT_RIGHT = 'right'

ALIGN_TEXT_CHOICES = (
    (ALIGN_TEXT_NULL, "Unset"),
    (ALIGN_TEXT_LEFT, "Left"),
    (ALIGN_TEXT_CENTER, "Center"),
    (ALIGN_TEXT_RIGHT, "Right"),
    (ALIGN_TEXT_JUSTIFY, "Justify"),
)

BACKROUND_POSITION_TOP = 'top'
BACKROUND_POSITION_CENTER = 'center'
BACKROUND_POSITION_BOTTOM = 'bottom'
BACKROUND_POSITION_LEFT = 'left'
BACKROUND_POSITION_RIGHT = 'right'

BACKROUND_POSITION_CHOICES = (
    (BACKROUND_POSITION_TOP, "Top"),
    (BACKROUND_POSITION_CENTER, "Center"),
    (BACKROUND_POSITION_BOTTOM, "Bottom"),
    (BACKROUND_POSITION_LEFT, "Left"),
    (BACKROUND_POSITION_RIGHT, "Right"),
)

LANGUAGE_FR = 'fr'
LANGUAGE_EN = 'en'
LANGUAGE_DE = 'de'
LANGUAGE_NL = 'nl'
LANGUAGE_ES = 'es'
LANGUAGE_IT = 'it'
LANGUAGES = [
    (LANGUAGE_FR, 'French'),
    (LANGUAGE_EN, 'English'),
]
LOCALES = {
    LANGUAGE_FR: 'fr-FR',
    LANGUAGE_EN: 'en-EN',
}



from wagtail.core import blocks

from webspace.cms.blocks.choice import AlignTextChoiceBlock
from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    ButtonsBlock, EntryBlock, FormBlock


class StreamContentEntry(EntryBlock):
    animation = blocks.BooleanBlock(required=False, help_text="Animation")
    align = AlignTextChoiceBlock(required=False)
    content = blocks.StreamBlock(
        [
            ('text', TextBlock()),
            ('buttons', ButtonsBlock()),
            ('form', FormBlock()),

        ],
        required=False
    )

    def mock(self, align='center', button_1=constants.BUTTON_PRIMARY,
             button_2=constants.BUTTON_PRIMARY_FULL, *args, **kwargs):
        self.mock_data.update({
            'type': 'stream_content',
            'value': {
                'content': [
                    {
                        'type': 'text',
                        'value': {
                            'value': self.text_first_content,
                        }
                    },
                    {
                        'type': 'buttons',
                        'value': [{
                            'type': 'button',
                            'value': self.button(button_1)
                        }, {
                            'type': 'button',
                            'value': self.button(button_2)
                        }],
                    },
                ],
                'align': align
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/stream_content.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Stream Content"



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import EntryBlock, EmbedWithSizeBlock


class EmbedEntry(EntryBlock):
    amp_scripts = ['iframe']
    animation = blocks.BooleanBlock(required=False, help_text="Animation")
    embed = EmbedWithSizeBlock()

    def mock(self, size_media='m', *args, **kwargs):
        self.mock_data.update({
            'type': 'embed',
            'value': {
                'embed': {
                    "link": self.URL_EMBED,
                    'size': size_media
                }
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/embed.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Embed"



from wagtail.documents.models import Document, AbstractDocument
from django.db import models


class AMyDocument(AbstractDocument):
    #  Dimensions for SVG

    width = models.IntegerField(
        default=None,
        blank=True,
        null=True,
        help_text="for SVG"
    )
    height = models.IntegerField(
        default=None,
        blank=True,
        null=True,
        help_text="for SVG"
    )

    admin_form_fields = Document.admin_form_fields + (
        'width',
        'height'
    )

    def get_size(self):
        return '500x500'

    class Meta:
        app_label = 'cms'
        abstract = True



# Generated by Django 3.0.7 on 2020-07-02 20:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0005_auto_20200702_1830'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='calendly',
        ),
        migrations.RemoveField(
            model_name='user',
            name='description',
        ),
        migrations.RemoveField(
            model_name='user',
            name='facebook',
        ),
        migrations.RemoveField(
            model_name='user',
            name='image_presentation',
        ),
        migrations.RemoveField(
            model_name='user',
            name='instagram',
        ),
        migrations.RemoveField(
            model_name='user',
            name='linkedin',
        ),
        migrations.RemoveField(
            model_name='user',
            name='pinterest',
        ),
        migrations.RemoveField(
            model_name='user',
            name='title',
        ),
        migrations.RemoveField(
            model_name='user',
            name='twitter',
        ),
        migrations.RemoveField(
            model_name='user',
            name='youtube',
        ),
    ]



import os
import environ
import webspace
from webspace.cms import constants
from webspace.settings import base as base_settings
import pkg_resources

BASE_DIR = os.environ['BASE_DIR']
env = environ.Env()
environ.Env.read_env(BASE_DIR + '/.env')

#  Vars

path_webspace = os.path.dirname(webspace.__file__)
DEBUG = env.bool('DEBUG', default=True)
IS_WEBSPACE = env.bool('IS_WEBSPACE', default=False)
SITE_NAME = env.str('APP_NAME')
DOMAINS_NAME = env.list('DOMAINS_NAME')
BUCKET_NAME = env.str('BUCKET_NAME')
BUCKET_URL = env.str('BUCKET_URL')
BUCKET_URL_CDN = env.str('BUCKET_URL_CDN')
SENDGRID_SK = env.str('SENDGRID_SK', default=None)
YANDEX_TRANSLATE_KEY = env.str('YANDEX_TRANSLATE_KEY')
DATABASES = {
    'default': env.db(
        'DATABASE',
        default='psql://postgres:password@127.0.0.1:5432/webspacedb',
    )
}
VERSION = base_settings.get_package_version(os.path.join(BASE_DIR, 'package.json'))
if IS_WEBSPACE:
    VERSION_WEBSPACE = VERSION
else:
    VERSION_WEBSPACE = pkg_resources.get_distribution("webspace").version


# Django

SECRET_KEY = base_settings.generate_secret_key()
SITE_ID = 1
ALLOWED_HOSTS = DOMAINS_NAME + base_settings.ALLOWED_HOSTS_DEV

INSTALLED_APPS = (['webspace.cms.apps.CmsConfig'] if IS_WEBSPACE else ['cms.apps.CmsConfig']) + base_settings.INSTALLED_APPS
MIDDLEWARE = base_settings.MIDDLEWARE
TEMPLATES = base_settings.get_templates(BASE_DIR, IS_WEBSPACE, path_webspace)
WSGI_APPLICATION = 'wsgi.application'
LOGGING = base_settings.LOGGING
DATA_UPLOAD_MAX_NUMBER_FIELDS = 10240
ROOT_URLCONF = 'urls' if IS_WEBSPACE else 'cms.urls'
LOGIN_URL = '/admin_W3cJ32mq63V45CLvmjNbsqSJ32mq63V45CL/login/'
if not DEBUG:

    """
    SECURE_HSTS_SECONDS = 50000
    SECURE_HSTS_INCLUDE_SUBDOMAINS = True
    SECURE_HSTS_PRELOAD = True
    SECURE_SSL_REDIRECT = True
    SECURE_REFERRER_POLICY = "same-origin"
    """

    SESSION_COOKIE_SECURE = True
    CSRF_COOKIE_SECURE = True
    SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
    os.environ['HTTPS'] = "on"
    os.environ['wsgi.url_scheme'] = "https"
    base_settings.run_sentry()


#  User

AUTH_USER_MODEL = "account.User"
AUTH_PASSWORD_VALIDATORS = base_settings.AUTH_PASSWORD_VALIDATORS

# Languages

LANGUAGE_CODE = 'fr-FR'
TIME_ZONE = 'Europe/Paris'
USE_I18N = True
USE_L10N = True
USE_TZ = True
ROSETTA_ENABLE_TRANSLATION_SUGGESTIONS = True
ROSETTA_WSGI_AUTO_RELOAD = True
ROSETTA_UWSGI_AUTO_RELOAD = True
LANGUAGES = constants.LANGUAGES
LOCALE_PATHS = [
    os.path.join(path_webspace, 'webspace/cms/locale' if IS_WEBSPACE else 'cms/locale'),
]


#  Files

STATICFILES_FINDERS = base_settings.STATICFILES_FINDERS
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static')] if IS_WEBSPACE else [os.path.join(path_webspace, 'cms/static')]
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATIC_URL = '/static/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'mediafiles')
MEDIA_URL = BUCKET_URL
DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
DATA_UPLOAD_MAX_MEMORY_SIZE = 26214400

#  AWS

AWS_ACCESS_KEY_ID = env.str('AWS_ACCESS_KEY_ID')
AWS_SECRET_ACCESS_KEY = env.str('AWS_SECRET_ACCESS_KEY')
AWS_S3_REGION_NAME = 'eu-west-3'
AWS_S3_CUSTOM_DOMAIN = BUCKET_URL_CDN
EMAIL_BACKEND = 'django_ses.SESBackend'
AWS_SES_REGION_NAME = 'eu-west-1'
AWS_SES_REGION_ENDPOINT = 'email.eu-west-1.amazonaws.com'
DEFAULT_FROM_EMAIL = 'Snoweb <hello@snoweb.fr>'
EMAIL_USE_SSL = True
AWS_S3_OBJECT_PARAMETERS = {
    'CacheControl': 'public, max-age=31536000',
}
AWS_IS_GZIPPED = True
AWS_STORAGE_BUCKET_NAME = BUCKET_NAME
AWS_DEFAULT_ACL = 'public-read'
AWS_LOCATION = 'www/'
FOLDER_FILE_UPLOAD_S3 = 'www'
URL_BUCKET_FILE = 'https://s3-eu-west-3.amazonaws.com/' + AWS_STORAGE_BUCKET_NAME + '/' + FOLDER_FILE_UPLOAD_S3
S3DIRECT_REGION = 'eu-west-3'
AWS_S3_FILE_OVERWRITE = False

# Wagtail

WAGTAIL_SITE_NAME = SITE_NAME
WAGTAILDOCS_SERVE_METHOD = 'direct'
WAGTAIL_BLOG_AUTHOR_PAGE = 'account.User'
WAGTAIL_BLOG_POSTS_PER_PAGE = 25
RICH_TEXT_FEATURES = base_settings.RICH_TEXT_FEATURES
WAGTAILDOCS_DOCUMENT_MODEL = 'cms.MyDocument'

#  Bakery

BUILD_DIR = os.path.join(BASE_DIR, 'cms/templates/build')
BAKERY_VIEWS = (
    'webspace.bakery.views.wagtail.AllBuildablePagesView',
    'webspace.bakery.views.wagtail.BlogIndexTagPagesView',
    'webspace.bakery.views.wagtail.PortfolioIndexTagPagesView',
)
BAKERY_GZIP = True


#  Content Security Policy

CSP_DEFAULT_SRC = (
    "'self'",
    "releases.wagtail.io",
)
CSP_MANIFEST_SRC = (
    "'self'",
    'data:',
)
CSP_STYLE_SRC = (
    "'self'",
    'fonts.googleapis.com',
    "'unsafe-inline'",
)
CSP_SCRIPT_SRC = (
    "'self'",
    "cdn.ampproject.org",
    "www.google-analytics.com",
    "www.googletagmanager.com",
    "'unsafe-eval'",
    "'unsafe-inline'",
    "assets.calendly.com",
)

CSP_FONT_SRC = (
    "'self'",
    'fonts.googleapis.com',
    'fonts.gstatic.com',
    'data:',
    'blob:',
)
CSP_IMG_SRC = (
    "'self'",
    BUCKET_URL_CDN,
    'www.gravatar.com',
    "www.google-analytics.com",
    "www.googletagmanager.com",
    'data:',
)
CSP_FRAME_SRC = (
    "'self'",
    '*.vimeo.com',
    '*.youtube.com',
    'www.facebook.com',
    'assets.calendly.com',
    'calendly.com',
)

CSP_CONNECT_SRC = (
    "'self'",
    BUCKET_URL_CDN,
    "cdn.ampproject.org",
    "www.googletagmanager.com",
    "releases.wagtail.io",
    'fonts.googleapis.com',
    '*.vimeo.com',
    '*.youtube.com',
    'www.facebook.com',
    "www.google-analytics.com",
    'fonts.gstatic.com',
    "assets.calendly.com",
)



import os.path

from .utils import amp_mode_active


class AmpMixin:

    @property
    def amp_template(self):
        name, ext = os.path.splitext(super().get_template({}))
        return name + '_amp' + ext

    def get_template(self, request):
        if amp_mode_active():
            return self.amp_template
        return super().get_template(request)

    def get_url(self, request=None, current_site=None):
        urls = super().get_url(request, current_site)
        if amp_mode_active():
            urls = urls.replace('/amp', '')
            return '/amp%s' % urls
        return urls



from __future__ import absolute_import, unicode_literals
from datetime import datetime
from django.core import management
from celery import Celery
import os
from django.conf import settings

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
app = Celery('webspace.bakery')
app.config_from_object('webspace.bakery.celeryconfig', namespace='CELERY')
app.conf.task_default_queue = settings.SITE_NAME
app.control.purge()
app.autodiscover_tasks()


@app.task(bind=True)
def bakery_build(self):
    from .models import TaskBuild
    task_obj = TaskBuild.objects.create()
    task_obj.task_id = self.request.id
    task_obj.save()
    management.call_command('build')
    task_obj.date_end = datetime.now()
    task_obj.ready = True
    task_obj.save()



import logging
from django.db import models
from django.conf import settings
from django.template.response import TemplateResponse
from django.http import HttpResponse
from django.utils import translation
from wagtail.core.models import Site


from webspace.cms.amp.utils import amp_mode_active
from webspace.loader import get_model

logger = logging.getLogger('bakery')


class BuildableModel(models.Model):
    detail_views = []

    def _get_view(self, name):
        from django.urls import get_callable
        return get_callable(name)

    def _build_related(self):
        pass

    def _build_extra(self):
        pass

    def _unbuild_extra(self):
        pass

    def build(self):
        for detail_view in self.detail_views:
            view = self._get_view(detail_view)
            view().build_object(self)
        self._build_extra()
        self._build_related()

    def unbuild(self):
        for detail_view in self.detail_views:
            view = self._get_view(detail_view)
            view().unbuild_object(self)
        self._unbuild_extra()
        # _build_related again to kill the object from RSS etc.
        self._build_related()

    def get_absolute_url(self):
        return self.get_full_url()

    class Meta:
        abstract = True


class WagtailPageBakeryModel(BuildableModel):
    detail_views = ['webspace.bakery.views.wagtail.AllBuildablePagesView']

    def serve(self, request, extra_path_file='', *args, **kwargs):
        is_building = request.GET.get('build', False)
        request.is_preview = getattr(request, 'is_preview', False)

        #  Remove settings.DEBUG if you want to test static page

        if settings.DEBUG or request.is_preview or is_building:
            self.active_language(request)
            logger.debug('Serving TemplateResponse')
            return TemplateResponse(
                request,
                self.get_template(request),
                self.get_context(request, *args, **kwargs)
            )
        else:
            site = self.get_site()
            path_file = self.relative_url(site)
            index = 'index.html' if request.user_agent.is_pc else 'index-mobile.html'
            if amp_mode_active():
                index = index.replace('.html', '-amp.html')
                path_file = path_file.replace('/amp', '')
            with open(settings.BUILD_DIR + '/' + site.hostname + '/' + path_file + extra_path_file + index, "rb") as fd:
                compressed = fd.read()
                response = HttpResponse(compressed)
                response['Content-Encoding'] = 'gzip'
                response['Content-Length'] = str(len(compressed))
                logger.debug('Serving Static File')
                return response

    def active_language(self, request):
        WebspaceSettings = get_model('cms', 'WebspaceSettings')
        site = Site.find_for_request(request)
        ws_settings = WebspaceSettings.for_site(site)
        if ws_settings.language:
            translation.activate(ws_settings.language)

    class Meta:
        abstract = True



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import \
    SvgBlock, \
    ImageBlock, \
    TextBlock, \
    EntryBlock


class SvgCell(SvgBlock):
    pass


class ImageCell(ImageBlock):
    pass


class TextCell(TextBlock):
    pass


class TableEntry(EntryBlock):
    rows = blocks.StreamBlock([
        ('cells', blocks.StreamBlock([
            ('text', TextCell()),
            ('svg', SvgCell()),
            ('image', ImageCell()),
        ], min_num=1)),
    ], min_num=1)

    def mock(self, *args, **kwargs):
        if 'theme' in kwargs:
            svg = self.SVG_ICON_LIGHT \
                if kwargs['theme'] == constants.THEME_LIGHT \
                else self.SVG_ICON_SPACE
        else:
            svg = self.SVG_ICON_SPACE
        if 'theme' in kwargs:
            image = self.IMG_SQUARE_LIGHT if kwargs['theme'] == constants.THEME_LIGHT \
                else self.IMG_SQUARE_SPACE
        else:
            image = self.IMG_SQUARE_SPACE
        cell_text = {
            'type': 'text',
            'value': {
                'value': self.p,
            }
        }
        cell_svg = {
            'type': 'svg',
            'value': {
                'file': self.file(svg).id,
            }
        }
        cell_image = {
            'type': 'image',
            'value': {
                'file': self.file(image).id,
            }
        }

        self.mock_data.update({
            'type': 'table',
            'value': {
                'rows': [
                    {
                        'type': 'cells',
                        'value': [cell_text, cell_text, cell_text, cell_text]
                    },
                    {
                        'type': 'cells',
                        'value': [cell_text, cell_image, cell_text, cell_text]
                    },
                    {
                        'type': 'cells',
                        'value': [cell_text, cell_text, cell_text, cell_text]
                    },
                    {
                        'type': 'cells',
                        'value': [cell_text, cell_text, cell_text, cell_svg]
                    },
                ]
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/table.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Table"



from lxml import etree
import requests
import logging

from django import template
from django.conf import settings
from wagtail.embeds.embeds import get_embed
from wagtail.embeds.exceptions import EmbedException
from wagtail.core.models import Site

from webspace.cms import constants
from webspace.cms.amp.utils import amp_mode_active
from webspace.cms.amp.mixins import AmpMixin

logger = logging.getLogger('amp')

register = template.Library()

SIZES_IMG = {
    's-icon x0-5': 10,
    's-icon x1': 20,
    's-icon x1-5': 30,
    's-icon x2': 40,
    's-icon x3': 60,
    's-icon x6': 120,
}

AMP_SCRIPTS = {
    'carousel': "<script async custom-element='amp-carousel' src='https://cdn.ampproject.org/v0/amp-carousel-0.2.js'></script>",
    'iframe': "<script async custom-element='amp-iframe' src='https://cdn.ampproject.org/v0/amp-iframe-0.1.js'></script>",
    'accordion': "<script async custom-element='amp-accordion' src='https://cdn.ampproject.org/v0/amp-accordion-0.1.js'></script>",
    'form': "<script async custom-element='amp-form' src='https://cdn.ampproject.org/v0/amp-form-0.1.js'></script>"
}


class AMPImage(template.Node):

    def __init__(self, nodelist):
        self.nodelist = nodelist

    def get_match(self, classname):
        for key, value in SIZES_IMG.items():
            if key in classname:
                return key
        return False

    def render(self, context):
        if amp_mode_active():
            html = self.nodelist.render(context)
            tree = etree.XML(html)
            classname = tree.get('class')
            layout = tree.get('data-layout', 'responsive')
            width = tree.get('data-width', '500')
            height = tree.get('data-height', '500')

            match = None
            if classname:
                match = self.get_match(classname)

            # Check icons or custom
            if match:
                tree.set('layout', layout)
                tree.set('width', str(SIZES_IMG[match]))
                tree.set('height', str(SIZES_IMG[match]))
            else:
                tree.set('layout', layout)
                if width and height:
                    tree.set('width', width)
                    tree.set('height', height)

            # Check lazy
            lazy_src = tree.get('data-src')
            if lazy_src:
                tree.set('src', lazy_src)
                tree.set('data-src', '')

            #  Replacement HTML
            ret = etree.tostring(tree).decode()
            ret = ret.replace('<img ', '<amp-img ')
            ret = ret.replace('/>', '></amp-img>')
            return ret
        return self.nodelist.render(context)


@register.tag('amp_img')
def amp_img(parser, token):
    nodelist = parser.parse(('endamp_img',))
    parser.delete_first_token()
    return AMPImage(nodelist=nodelist)


class AMPStyles(template.Node):

    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        if amp_mode_active():
            html = self.nodelist.render(context)
            tree = etree.XML(html)
            href = tree.get('href')
            request = context['request']
            http = 'https://' if not settings.DEBUG else 'http://'
            site = Site.find_for_request(request)
            host = site.hostname
            if host == 'localhost':
                host += ':8080'
            url = http + host + href
            logger.debug(url)
            response = requests.get(url)
            css = response.content.decode().replace('\n', '').replace('!important', '')
            ret = "<style amp-custom>%s</style>" % css
            return ret
        return self.nodelist.render(context)


@register.tag('amp_styles')
def amp_styles(parser, token):
    nodelist = parser.parse(('endamp_styles',))
    parser.delete_first_token()
    return AMPStyles(nodelist=nodelist)


@register.inclusion_tag('%s/templatetags/content-safe.html' % constants.BLOCK_TEMPLATES_PATH, takes_context=True)
def amp_scripts(context):
    scripts = []
    page = context['page']
    for block in page.body:
        if hasattr(block.block, 'amp_scripts'):
            for script in block.block.amp_scripts:
                if script not in scripts:
                    if block.block_type == 'cards' and script == 'carousel':
                        if block.value['carousel']:
                            scripts.append(script)
                    if block.block_type == 'component_text' and script == 'iframe':
                        for media in block.value['component']:
                            if media.block_type == 'embed':
                                scripts.append(script)
                    if block.block_type == 'component_text' and script == 'form':
                        for media in block.value['component']:
                            if media.block_type == 'form':
                                scripts.append(script)
                    else:
                        scripts.append(script)
    scripts = list(set(scripts))
    html = ''

    for script in scripts:
        html += AMP_SCRIPTS[script]
    return {
        'content': html
    }


@register.inclusion_tag('%s/templatetags/content-safe.html' % constants.BLOCK_TEMPLATES_PATH, takes_context=True)
def amp_canonical(context):
    page = context['page']
    if isinstance(page, AmpMixin):
        return {
            'content': "<link rel='amphtml' href='https://%s" % context[
                'request'].get_host() + "/amp%s'>" % context[
                           'request'].path.replace('?build=true', '')
        }
    return None


@register.filter
def amp_embed(url):
    try:
        embed = get_embed(url)
        tree = etree.XML(embed.html.replace('allowfullscreen', ''))
        tree.set('layout', 'responsive')
        tree.set('sandbox', 'allow-scripts allow-same-origin allow-presentation')

        #  Replacement HTML
        ret = etree.tostring(tree).decode()
        ret = ret.replace('<iframe ', '<amp-iframe ')
        ret = ret.replace('/>', '></amp-iframe>')

        return ret
    except EmbedException:
        return "<amp-iframe " \
               "width='480' " \
               "height='270' " \
               "sandbox='allow-scripts allow-same-origin allow-presentation' " \
               "layout='responsive' " \
               "src='%s'></amp-iframe>" % url



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.choice import ThemeChoiceBlock
from webspace.cms.blocks.common import \
    FormBlock, \
    EntryBlock


class FormEntry(EntryBlock):
    amp_scripts = ['form']
    theme_reverse = ThemeChoiceBlock(required=False)
    theme_content = ThemeChoiceBlock(required=False)

    form = FormBlock()

    def mock(self, *args, **kwargs):
        form = self.get_form('big')
        self.mock_data.update({
            'type': 'form',
            'value': {
                'form': {
                    'form': form.id
                }
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/form.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Form"



import logging
from django.http import HttpResponseRedirect
from django.template.response import TemplateResponse
import json
from django.core.serializers.json import DjangoJSONEncoder

from webspace.loader import get_model

Form = get_model('cms', 'Form')
FormSubmission = get_model('cms', 'FormSubmission')

logger = logging.getLogger('forms')


class FormMixin:

    def serve(self, request, *args, **kwargs):
        if request.method == 'POST' and 'form_id' in request.POST:
            try:
                form_instance = Form.objects.get(id=request.POST['form_id'])
                form = form_instance.get_form(request.POST, request.FILES, user=request.user)
                if form.is_valid():

                    logger.debug("Form is valid")

                    form_data = json.dumps(form.cleaned_data, cls=DjangoJSONEncoder)

                    for action in form_instance.actions:
                        action.value.run(request, form_instance, form_data)

                    fs = FormSubmission.objects.create(
                        form_data=form_data,
                        page=self,
                        form=form_instance
                    )
                    fs.save()

                    if form_instance.redirection_page:
                        url = form_instance.redirection_page.get_full_url()
                        logger.debug("Redirection page")
                        return HttpResponseRedirect(url)

                    if form_instance.redirection_url:
                        logger.debug("Redirection URL")
                        return HttpResponseRedirect(form_instance.redirection_url)
                else:

                    logger.debug("Form is not valid")

                    request.session['current_form_id'] = form_instance.id
                    return TemplateResponse(
                        request,
                        self.get_template(request, *args, **kwargs),
                        self.get_context(request, *args, **kwargs)
                    )
            except Form.DoesNotExist:
                pass

        logger.debug("Call super")
        request.session['current_form_id'] = None
        return super().serve(request, *args, **kwargs)

    class Meta:
        abstract = True



from django.db import models
from wagtail.admin.edit_handlers import FieldPanel
from wagtail.search import index
from wagtail.admin.edit_handlers import StreamFieldPanel
from wagtail.core.fields import StreamField
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail.images.blocks import ImageChooserBlock


class AGallery(index.Indexed, models.Model):
    help_text = models.CharField(max_length=100, default='', blank=True)

    medias = StreamField([
        ('image', ImageChooserBlock()),
        ('svg', DocumentChooserBlock()),
    ], blank=True)

    panels = [
        FieldPanel("help_text"),
        StreamFieldPanel('medias'),
    ]

    search_fields = [
        index.SearchField('help_text', partial_match=True),
    ]

    def __str__(self):
        return self.help_text

    class Meta:
        abstract = True
        app_label = 'cms'



from django.db import models
from django.conf import settings


class TaskBuild(models.Model):
    date_start = models.DateTimeField(null=True, blank=True, auto_now=True)
    date_end = models.DateTimeField(null=True, blank=True)
    task_id = models.CharField(max_length=100, default=None, null=True, blank=True)
    ready = models.BooleanField(default=False)

    def __str__(self):
        return str(self.task_id)

    class Meta:
        ordering = ['-date_start']


class VersionBuild(models.Model):
    key = models.CharField(max_length=100, default=None, null=True, blank=True)
    total_build = models.IntegerField(default=0)

    def __str__(self):
        return "%s-%s" % (self.key, self.version)

    @staticmethod
    def get():
        bv, created = VersionBuild.objects.get_or_create(
            key='default',
        )
        if created:
            bv.save()
        return bv

    def minor(self):
        self.total_build += 1
        self.save()

    @property
    def version(self):
        return "%s-%s" % (settings.VERSION, str(self.total_build))



# Generated by Django 3.0.7 on 2020-07-09 16:49

from django.db import migrations, models
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks
import wagtail.images.blocks
import wagtail.snippets.blocks
import webspace.cms.blocks.static.social_links
import webspace.cms.blocks.static.social_share


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0009_auto_20200709_1329'),
    ]

    operations = [
        migrations.AddField(
            model_name='form',
            name='animation',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='blogpage',
            name='h1',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='Titre intro'),
        ),
        migrations.AlterField(
            model_name='blogpage',
            name='intro',
            field=models.CharField(blank=True, default='', help_text="Texte d'introduction qui s'affiche sur un block article de présentation", max_length=500),
        ),
        migrations.AlterField(
            model_name='blogpage',
            name='intro_page',
            field=wagtail.core.fields.RichTextField(blank=True, default='', help_text="Texte qui s'affiche sur un la page de l'article"),
        ),
        migrations.AlterField(
            model_name='genericpage',
            name='body',
            field=wagtail.core.fields.StreamField([('svg', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('image', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('text', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False)), ('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))]))])), ('cards', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('theme_reverse', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('carousel', wagtail.core.blocks.BooleanBlock(required=False)), ('cards', wagtail.core.blocks.StreamBlock([('custom', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))])), ('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(label='Button link', required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Button Page', required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, label='Button nouvel onglet', required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')], label='Button type', required=False))])), ('icon', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))], label='Icon')), ('media', wagtail.core.blocks.StreamBlock([('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))], max_num=1, required=False))]))], min_num=1))])), ('component_text', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('titles', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))], label='Titres')), ('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))], label='Description')), ('reverse', wagtail.core.blocks.BooleanBlock(help_text="Permet de d'intervertir le component et la zone de texte", required=False)), ('section', wagtail.core.blocks.BooleanBlock(help_text='Permet de sectionner la zone de texte', required=False)), ('animation', wagtail.core.blocks.BooleanBlock(help_text='Animation', required=False)), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False)), ('component', wagtail.core.blocks.StreamBlock([('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('embed', wagtail.core.blocks.StructBlock([('link', wagtail.core.blocks.URLBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))])), ('form', wagtail.core.blocks.StructBlock([('form', wagtail.snippets.blocks.SnippetChooserBlock('cms.Form', required=True))]))], max_num=1, required=False)), ('buttons', wagtail.core.blocks.StreamBlock([('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(label='Button link', required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Button Page', required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, label='Button nouvel onglet', required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')], label='Button type', required=False))]))], max_num=2, required=False))])), ('grid_info', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('infos', wagtail.core.blocks.StreamBlock([('svg_info', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('title', wagtail.core.blocks.CharBlock()), ('text_hover', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))]))])), ('image_info', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False)), ('title', wagtail.core.blocks.CharBlock()), ('text_hover', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))]))]))], min_num=1))])), ('medias_line', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('medias', wagtail.core.blocks.StreamBlock([('svg_label', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False)), ('label', wagtail.core.blocks.CharBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))])), ('image_label', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('label', wagtail.core.blocks.CharBlock(required=False)), ('page', wagtail.core.blocks.PageChooserBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))]))], min_num=1))])), ('timeline', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('animation', wagtail.core.blocks.BooleanBlock(help_text='Animation', required=False)), ('items', wagtail.core.blocks.StreamBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))]))], min_num=1))])), ('buttons', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('align', wagtail.core.blocks.ChoiceBlock(choices=[(None, 'Unset'), ('left', 'Left'), ('center', 'Center'), ('right', 'Right'), ('justify', 'Justify')], required=False)), ('buttons', wagtail.core.blocks.StreamBlock([('button', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=False)), ('link', wagtail.core.blocks.URLBlock(label='Button link', required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Button Page', required=False)), ('open_new_tab', wagtail.core.blocks.BooleanBlock(default=False, label='Button nouvel onglet', required=False)), ('type', wagtail.core.blocks.ChoiceBlock(choices=[('primary-light', 'Primary Light'), ('primary-full', 'Primary Full'), ('secondary-light', 'Secondary Light'), ('secondary-full', 'Secondary Full'), ('tertiary-light', 'Tertiary Light'), ('tertiary-full', 'Tertiary Full')], label='Button type', required=False))]))], max_num=3))])), ('calendly', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('link', wagtail.core.blocks.URLBlock(required=False))])), ('articles', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('articles', wagtail.core.blocks.StreamBlock([('article', wagtail.core.blocks.PageChooserBlock(page_type=['cms.BlogPage'], required=False))], min_num=1))])), ('embed', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('animation', wagtail.core.blocks.BooleanBlock(help_text='Animation', required=False)), ('embed', wagtail.core.blocks.StructBlock([('link', wagtail.core.blocks.URLBlock(required=False)), ('size', wagtail.core.blocks.ChoiceBlock(choices=[('xs', 'XS'), ('s', 'S'), ('m', 'M'), ('l', 'L'), ('x', 'X'), ('xl', 'XL'), ('full', 'Full')], required=False))]))])), ('social_share', webspace.cms.blocks.static.social_share.SocialShare()), ('social_links', webspace.cms.blocks.static.social_links.SocialLinks()), ('table', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('rows', wagtail.core.blocks.StreamBlock([('cells', wagtail.core.blocks.StreamBlock([('text', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))])), ('svg', wagtail.core.blocks.StructBlock([('file', wagtail.documents.blocks.DocumentChooserBlock(required=False))])), ('image', wagtail.core.blocks.StructBlock([('file', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False))]))], min_num=1))], min_num=1))])), ('accordion', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('items', wagtail.core.blocks.StreamBlock([('classic', wagtail.core.blocks.StructBlock([('head', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))], label='Head')), ('content', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))], label='Head'))]))], min_num=1))])), ('numbers', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('items', wagtail.core.blocks.StreamBlock([('classic', wagtail.core.blocks.StructBlock([('number', wagtail.core.blocks.IntegerBlock(required=True)), ('unit', wagtail.core.blocks.CharBlock(help_text='unité de mesure', required=False)), ('content', wagtail.core.blocks.StructBlock([('value', wagtail.core.blocks.RichTextBlock(features=['h1', 'h2', 'h3', 'h4', 'bold', 'italic', 'link', 'ol', 'ul', 'hr', 'code-block', 'blockquote', 'strikethrough', 'mark'], label='Text', required=False))], label='Content'))]))], min_num=1))])), ('form', wagtail.core.blocks.StructBlock([('bg_desktop', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('bg_mobile', wagtail.core.blocks.StreamBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('svg', wagtail.documents.blocks.DocumentChooserBlock())], max_num=1, required=False)), ('svg_bg_position', wagtail.core.blocks.ChoiceBlock(choices=[('top', 'Top'), ('center', 'Center'), ('bottom', 'Bottom'), ('left', 'Left'), ('right', 'Right')], required=False)), ('container', wagtail.core.blocks.ChoiceBlock(choices=[('regular', 'Regular'), ('content', 'Content (blog)'), ('full', 'Full (width 100%)')], required=False)), ('padding_top', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('padding_bottom', wagtail.core.blocks.BooleanBlock(default=True, required=False)), ('theme', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('theme_reverse', wagtail.core.blocks.ChoiceBlock(choices=[('space', 'Primary'), ('space-inverse', 'Primary Inverse'), ('light', 'Secondary')], required=False)), ('form', wagtail.core.blocks.StructBlock([('form', wagtail.snippets.blocks.SnippetChooserBlock('cms.Form', required=True))]))]))], blank=True),
        ),
    ]



import json
import requests
import logging

logger = logging.getLogger('api')


class API:
    api_root = 'https://api.snoweb.fr'

    @staticmethod
    def request(path, data, method='post'):
        res = requests.request(
            url='%s%s' % (API.api_root, path),
            method=method,
            data=json.dumps(data),
            headers={
                "Content-Type": "application/json",
            }
        )
        if res.status_code != 200:
            logger.error('Error API')
            logger.error(str(res.content))
            return None
        logger.debug('Request API OK')
        return res.content



import logging
import re
from django import template

from wagtail.embeds.embeds import get_embed
from wagtail.embeds.exceptions import EmbedException

from webspace.loader import get_model
from webspace.cms import constants

register = template.Library()
logger = logging.getLogger('forms')
IconSnippet = get_model('cms', 'IconSnippet')


#  Icons

@register.filter
def ico(icon, theme):
    if icon:
        if theme == 'space' or theme == 'space-inverse':
            return icon['space']
        return icon['light']
    return None


@register.filter
def ico_astro(icons, level):
    return icons['astro_level_%s' % level]


@register.filter
def ico_snippet(icon, theme):
    if not hasattr(icon, theme):
        theme = 'space'
    doc = eval('icon.%s' % theme)
    if doc:
        return doc.file.url
    return IconSnippet.DEFAULT_LINK


@register.filter
def ico_get(icons, key):
    try:
        return icons[key]
    except:
        return None


#  Utils

@register.filter
def plur(value, arg='s'):
    if ',' not in arg:
        arg = ',' + arg
    bits = arg.split(',')
    if len(bits) > 2:
        return ''
    singular_suffix, plural_suffix = bits[:2]
    try:
        return singular_suffix if float(value) <= 1 else plural_suffix
    except ValueError:  # Invalid string that's not a number.
        pass
    except TypeError:  # Value isn't a string or a number; maybe it's a list?
        try:
            return singular_suffix if len(value) <= 1 else plural_suffix
        except TypeError:  # len() of unsized object.
            pass
    return ''


@register.filter
def embed(url):
    try:
        embed = get_embed(url)
        ret = embed.html.replace('width="480"', '')
        ret = ret.replace('height="270"', '')
        ret = ret.replace('src=', 'loading="lazy" title="embed" data-src=')
        return ret
    except EmbedException:
        return "<iframe title='embed' loading='lazy' data-src='%s'></iframe>" % url


@register.filter
def strfix(value):
    return value.replace('\n', '')


@register.filter
def klass(ob):
    return re.sub('(((?<=[a-z])[A-Z])|([A-Z](?![A-Z]|$)))', '-\\1', ob.__class__.__name__).lower().strip('-')


@register.filter
def cached_form(form, request):
    if form:
        if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session[
            'current_form_id']:
            logger.debug("Take form cached")
            return form.get_form(request.POST, request.FILES, user=request.user)
        logger.debug("Take new form")
        return form.get_form()
    logger.debug("No forms")
    return []


@register.filter
def myimg(img, params):
    return img.get_rendition(params)


@register.filter
def theme_settings(theme, site):
    themes = {
        constants.THEME_SPACE: {
            'colors_uks': site.primary_color_uks,
            'bg_color': site.primary_bg_color,
        },
        constants.THEME_SPACE_INVERSE: {
            'colors_uks': site.primary_inverse_color_uks,
            'bg_color': site.primary_inverse_bg_color,
        },
        constants.THEME_LIGHT: {
            'colors_uks': site.secondary_color_uks,
            'bg_color': site.secondary_bg_color,
        },
        constants.THEME_LIGHT_INVERSE: {
            'colors_uks': site.secondary_inverse_color_uks,
            'bg_color': site.secondary_inverse_bg_color,
        }
    }
    return themes[theme] if theme in themes else None


@register.filter
def theme_reverse(theme):
    if '-inverse' in theme:
        return theme.replace('-inverse', '')
    return theme + '-inverse'


@register.filter
def debug(item):
    import pdb
    pdb.set_trace()
    return



from datetime import datetime
from django.core.management.base import BaseCommand
from wagtail.core.models import Page


class Command(BaseCommand):
    help = 'Page commands : update'

    def add_arguments(self, parser):
        parser.add_argument('action', type=str)
        parser.add_argument('extra', type=str, nargs='?', default='')

    def handle(self, *args, **options):
        eval('self.' + options['action'] + '(' + options['extra'] + ')')

    def update(self):
        for page in Page.objects.all():
            page.last_published_at = datetime.now()
            page.save()



import json
from os import listdir
from os.path import isfile, join
from django.core.files.images import ImageFile
from django.core.management.base import BaseCommand
from django.contrib.contenttypes.models import ContentType
from wagtail.core.models import Page, Site
from wagtail.images.models import Image
from wagtail_feeds.models import RSSFeedsSettings

from webspace.cms import constants
from webspace.loader import get_model, get_class
from webspace.cms.blocks.mocker import Mocker
from webspace.account.utils import get_test_account

# Classes
ArticlesEntry = get_class('cms.blocks.entries', 'ArticlesEntry')
ButtonsEntry = get_class('cms.blocks.entries', 'ButtonsEntry')
CardsEntry = get_class('cms.blocks.entries', 'CardsEntry')
EmbedEntry = get_class('cms.blocks.entries', 'EmbedEntry')
GridInfoEntry = get_class('cms.blocks.entries', 'GridInfoEntry')
ImageEntry = get_class('cms.blocks.entries', 'ImageEntry')
ComponentTextEntry = get_class('cms.blocks.entries', 'ComponentTextEntry')
MediasLineEntry = get_class('cms.blocks.entries', 'MediasLineEntry')
SvgEntry = get_class('cms.blocks.entries', 'SvgEntry')
TextEntry = get_class('cms.blocks.entries', 'TextEntry')
TimeLineEntry = get_class('cms.blocks.entries', 'TimeLineEntry')
CalendlyEntry = get_class('cms.blocks.entries', 'CalendlyEntry')
TableEntry = get_class('cms.blocks.entries', 'TableEntry')
AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
FormEntry = get_class('cms.blocks.entries', 'FormEntry')
GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')

SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
SocialShare = get_class('cms.blocks.static', 'SocialShare')


# Models
MenuItem = get_model('cms', 'MenuItem')
Menu = get_model('cms', 'Menu')
IconSnippet = get_model('cms', 'IconSnippet')
Navigation = get_model('cms', 'Navigation')
Person = get_model('cms', 'Person')


HomePage = get_model('cms', 'HomePage')
ContentPage = get_model('cms', 'ContentPage')
BlogPage = get_model('cms', 'BlogPage')
BlogIndexPage = get_model('cms', 'BlogIndexPage')
PortfolioPage = get_model('cms', 'PortfolioPage')
PortfolioIndexPage = get_model('cms', 'PortfolioIndexPage')

WebspaceSettings = get_model('cms', 'WebspaceSettings')
MyDocument = get_model('cms', 'MyDocument')
Form = get_model('cms', 'Form')
FormField = get_model('cms', 'FormField')
Gallery = get_model('cms', 'Gallery')


class Command(BaseCommand):
    help = 'Cms commands : init'

    def add_arguments(self, parser):
        parser.add_argument('action', type=str)
        parser.add_argument('extra', type=str, nargs='?', default='')

    def handle(self, *args, **options):
        eval('self.' + options['action'] + '(' + options['extra'] + ')')

    def init(self):
        #  Delete all data
        Site.objects.all().delete()
        Page.objects.all().delete()
        #  Image.objects.all().delete()
        #  MyDocument.objects.all().delete()
        Menu.objects.all().delete()
        MenuItem.objects.all().delete()
        Navigation.objects.all().delete()
        Form.objects.all().delete()
        FormField.objects.all().delete()
        Person.objects.all().delete()
        Gallery.objects.all().delete()

        article_entry = ArticlesEntry()
        buttons_entry = ButtonsEntry()
        cards_entry = CardsEntry()
        embed_entry = EmbedEntry()
        grid_info_entry = GridInfoEntry()
        image_entry = ImageEntry()
        component_text_entry = ComponentTextEntry()
        medias_line_entry = MediasLineEntry()
        svg_entry = SvgEntry()
        text_entry = TextEntry()
        time_line_entry = TimeLineEntry()
        calendly_entry = CalendlyEntry()
        table_entry = TableEntry()
        accordion_entry = AccordionEntry()
        numbers_entry = NumbersEntry()
        form_entry = FormEntry()
        gallery_entry = GalleryEntry()
        stream_content_entry = StreamContentEntry()

        social_links = SocialLinks()
        social_share = SocialShare()

        account = get_test_account()

        mocker = Mocker()

        # Create page content type

        page_content_type, created = ContentType.objects.get_or_create(
            model='page',
            app_label='wagtailcore'
        )

        # Root page

        root = Page.objects.create(
            title="Root",
            slug='root',
            content_type=page_content_type,
            path='0001',
            depth=1,
            numchild=1,
            url_path='/',
        )
        root.save()

        # -------------------------------- HomePage --------------------------------

        home_page = HomePage.objects.create(
            title="Home Page",
            slug='home',
            path='00010001',
            depth=2,
            numchild=0,
            body=json.dumps([
                component_text_entry.mock(bg=True),
                cards_entry.mock(stop=3, carousel=False, container='regular', theme=constants.THEME_LIGHT),
                component_text_entry.mock(size_component='l', reverse=True, section=True),
                cards_entry.mock(container='full'),
                component_text_entry.mock(size_component='l', theme=constants.THEME_LIGHT, section=True),
                cards_entry.mock(container='full', theme=constants.THEME_LIGHT),
                component_text_entry.mock(size_component='l', reverse=True),
                component_text_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        home_page.save()
        home_page_menu_id = mocker.menu(home_page)
        mocker.add_header_buttons(home_page)

        # Create default site

        site = Site.objects.create(
            hostname='localhost',
            port=8080,
            root_page_id=home_page.id,
            is_default_site=True
        )
        site.save()

        # -------------------------------- Content Pages --------------------------------

        content_page = ContentPage(
            title="Content Page",
            slug='content',
            body=json.dumps([
                component_text_entry.mock(),
                component_text_entry.mock(theme=constants.THEME_LIGHT),
                time_line_entry.mock(theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<h2>Loreum</h2>', align='center', theme=constants.THEME_SPACE),
                component_text_entry.mock(reverse=True, theme=constants.THEME_SPACE),
                component_text_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                component_text_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        home_page.add_child(instance=content_page)
        content_menu_id = mocker.menu(content_page)
        mocker.add_menu(content_page, home_page_menu_id)
        mocker.add_menu(home_page, content_menu_id)

        # -------------------------------- Blog Pages --------------------------------

        articles_page = BlogIndexPage(
            title="Articles",
            slug='articles',
            bg_desktop=json.dumps([{
                'type': 'svg',
                'value': mocker.file(mocker.SVG_BG_DESKTOP_SPACE).id
            }]),
            bg_mobile=json.dumps([{
                'type': 'svg',
                'value': mocker.file(mocker.SVG_BG_MOBILE_SPACE).id
            }]),
            h1=mocker.h,
            first_text=mocker.text_first_content
        )
        home_page.add_child(instance=articles_page)
        articles_menu_id = mocker.menu(articles_page)
        mocker.add_menu(articles_page, home_page_menu_id)
        mocker.add_menu(home_page, articles_menu_id)

        article_list = []
        i = 1
        while i < 3:
            file_desktop = mocker.SVG_BG_DESKTOP_SPACE if i % 2 else mocker.IMG_BG_DESKTOP_SPACE
            file_mobile = mocker.SVG_BG_MOBILE_SPACE if i % 2 else mocker.IMG_BG_MOBILE_SPACE
            cover = mocker.SVG_BLOG_COVER_LIGHT if i % 2 else mocker.IMG_BLOG_COVER_LIGHT

            article_page = BlogPage(
                title="Article %s" % (str(i)),
                slug='article-%s' % (str(i)),
                body=json.dumps([
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    svg_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    svg_entry.mock(force_file=mocker.SVG_CONTENT_HEIGHT_LIGHT, container='content',
                                   theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    image_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    image_entry.mock(force_file=mocker.IMG_CONTENT_HEIGHT_LIGHT, container='content',
                                     theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    embed_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                ]),
                author=mocker.get_person(),
                bg_desktop=json.dumps([{
                    'type': ('svg' if i % 2 else 'image'),
                    'value': mocker.file(file_desktop).id
                }]),
                bg_mobile=json.dumps([{
                    'type': ('svg' if i % 2 else 'image'),
                    'value': mocker.file(file_mobile).id
                }]),
                cover=json.dumps([{
                    'type': ('svg' if i % 2 else 'image'),
                    'value': mocker.file(cover).id
                }]),
                intro=mocker.h,
                intro_page=mocker.text_first_content,
                h1=mocker.h,
            )
            article_page.tags.add('Foo' if i % 2 else 'Bar')
            articles_page.add_child(instance=article_page)
            mocker.menu(article_page, articles_menu_id)
            mocker.add_menu(article_page, home_page_menu_id)
            article_list.append(article_page)
            i += 1

        related = {
            'type': 'article',
            'value': article_list[0].id
        }
        for article in article_list:
            article.related_blogs = json.dumps([
                related, related, related
            ])
            article.save()

        # -------------------------------- Portfolio Pages --------------------------------

        portfolios_page = PortfolioIndexPage(
            title="Portfolio",
            slug='portfolio',
            bg_desktop=json.dumps([{
                'type': 'svg',
                'value': mocker.file(mocker.SVG_BG_DESKTOP_SPACE).id
            }]),
            bg_mobile=json.dumps([{
                'type': 'svg',
                'value': mocker.file(mocker.SVG_BG_MOBILE_SPACE).id
            }]),
            first_text=mocker.text_first_content
        )
        home_page.add_child(instance=portfolios_page)
        portfolios_menu_id = mocker.menu(portfolios_page)
        mocker.add_menu(portfolios_page, home_page_menu_id)
        mocker.add_menu(home_page, portfolios_menu_id)

        portfolio_list = []
        i = 1
        while i < 3:
            cover = mocker.SVG_BLOG_COVER_LIGHT if i % 2 else mocker.IMG_BLOG_COVER_LIGHT
            portfolio_page = PortfolioPage(
                title="Portfolio %s" % (str(i)),
                slug='portfolio-%s' % (str(i)),
                body=json.dumps([
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    svg_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    svg_entry.mock(force_file=mocker.SVG_CONTENT_HEIGHT_LIGHT, container='content',
                                   theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    image_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    image_entry.mock(force_file=mocker.IMG_CONTENT_HEIGHT_LIGHT, container='content',
                                     theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    embed_entry.mock(container='content', theme=constants.THEME_LIGHT),
                    text_entry.mock(container='content', theme=constants.THEME_LIGHT),
                ]),
                cover=json.dumps([{
                    'type': ('svg' if i % 2 else 'image'),
                    'value': mocker.file(cover).id
                }]),
                intro=mocker.h,
            )
            portfolio_page.tags.add('Uks' if i % 2 else 'Kaks')
            portfolios_page.add_child(instance=portfolio_page)
            mocker.menu(portfolio_page, portfolios_menu_id)
            mocker.add_menu(portfolio_page, home_page_menu_id)
            portfolio_list.append(portfolio_page)
            i += 1

        related = {
            'type': 'portfolio',
            'value': portfolio_list[0].id
        }
        for portfolio in portfolio_list:
            portfolio.related_portfolio = json.dumps([
                related, related, related
            ])
            portfolio.save()

        # -------------------------------- Example --------------------------------

        # -------------------------------- Cards --------------------------------

        block_page = ContentPage(
            title="Blocks",
            slug='blocks',
        )
        home_page.add_child(instance=block_page)
        block_menu_id = mocker.menu(block_page)
        mocker.add_menu(block_page, home_page_menu_id)
        mocker.add_menu(home_page, block_menu_id)

        carousel_page = ContentPage(
            title="Cards",
            slug='cards',
            body=json.dumps([
                text_entry.mock(txt='<h2>Cards Custom</h2>', align='center'),
                cards_entry.mock(stop=1, carousel=False, container='content'),
                cards_entry.mock(stop=2, carousel=False, container='regular'),
                cards_entry.mock(stop=3, carousel=False, container='regular'),

                cards_entry.mock(stop=1, carousel=False, theme=constants.THEME_LIGHT, container='content'),
                cards_entry.mock(stop=2, carousel=False, theme=constants.THEME_LIGHT, container='regular'),
                cards_entry.mock(stop=3, carousel=False, theme=constants.THEME_LIGHT, container='regular'),

                text_entry.mock(txt='<h2>Carousel Custom</h2>', align='center'),
                cards_entry.mock(container='full'),
                cards_entry.mock(container='full', theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=carousel_page)
        mocker.menu(carousel_page, block_menu_id)
        mocker.add_menu(carousel_page, home_page_menu_id)

        # -------------------------------- Component Text --------------------------------

        media_text_page = ContentPage(
            title="Component Text",
            slug='component-text',
            body=json.dumps([
                text_entry.mock(txt='<h2>Component Text Regular</h2>', align='center'),
                component_text_entry.mock(reverse=True),
                component_text_entry.mock(theme=constants.THEME_LIGHT),

                text_entry.mock(txt='<h2>Component Text Embed</h2>', align='center'),
                component_text_entry.mock(component='embed', size_component='xl'),

                text_entry.mock(txt='<h2>Component Text Form</h2>', align='center'),
                component_text_entry.mock(component='form'),

                text_entry.mock(txt='<h2>Component Text Size XL</h2>', align='center'),
                component_text_entry.mock(size_component='xl', reverse=True),
                component_text_entry.mock(size_component='xl', theme=constants.THEME_LIGHT),

                text_entry.mock(txt='<h2>Component Text Buttons</h2>', align='center'),
                component_text_entry.mock(
                    reverse=True,
                    button_1=constants.BUTTON_SECONDARY_FULL,
                    button_2=constants.BUTTON_SECONDARY
                ),
                component_text_entry.mock(
                    theme=constants.THEME_LIGHT,
                    button_1=constants.BUTTON_PRIMARY_FULL,
                    button_2=constants.BUTTON_PRIMARY
                ),

                text_entry.mock(txt='<h2>Component Text Background</h2>', align='center'),
                component_text_entry.mock(
                    reverse=True,
                    button_1=constants.BUTTON_TERTIARY_FULL,
                    button_2=constants.BUTTON_TERTIARY,
                    bg=True
                ),
                component_text_entry.mock(
                    theme=constants.THEME_LIGHT,
                    button_1=constants.BUTTON_SECONDARY_FULL,
                    button_2=constants.BUTTON_SECONDARY,
                    bg=True
                ),

                text_entry.mock(txt='<h2>Component Text Align</h2>', align='center'),
                component_text_entry.mock(
                    align='justify',
                    reverse=True,
                    button_1=constants.BUTTON_TERTIARY_FULL,
                    button_2=constants.BUTTON_TERTIARY,
                ),
                component_text_entry.mock(
                    theme=constants.THEME_LIGHT,
                    button_1=constants.BUTTON_SECONDARY_FULL,
                    button_2=constants.BUTTON_SECONDARY,
                    align='center'
                ),
            ])
        )
        block_page.add_child(instance=media_text_page)
        mocker.menu(media_text_page, block_menu_id)
        mocker.add_menu(media_text_page, home_page_menu_id)

        # -------------------------------- Text --------------------------------

        text_page = ContentPage(
            title="Text",
            slug='text',
            body=json.dumps([
                text_entry.mock(size='example', align='left'),
                text_entry.mock(size='example', align='left', theme=constants.THEME_LIGHT),

                text_entry.mock(size='normal', align='left'),
                text_entry.mock(size='normal', align='left', theme=constants.THEME_LIGHT),

                text_entry.mock(size='big', align='left'),
                text_entry.mock(size='big', align='left', theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=text_page)
        mocker.menu(text_page, block_menu_id)
        mocker.add_menu(text_page, home_page_menu_id)

        # -------------------------------- Image --------------------------------

        image_page = ContentPage(
            title="Images",
            slug='images',
            body=json.dumps([
                text_entry.mock(txt='<h2>JPG</h2>', align='center', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size XS</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='xs'),
                text_entry.mock(txt='<p>Size S</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='s'),
                text_entry.mock(txt='<p>Size M</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='m'),
                text_entry.mock(txt='<p>Size L</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='l'),
                text_entry.mock(txt='<p>Size X</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='x'),
                text_entry.mock(txt='<p>Size XL</p>', align='center', theme=constants.THEME_LIGHT),
                image_entry.mock(size='xl'),
                text_entry.mock(txt='<h2>SVG</h2>', align='center'),
                text_entry.mock(txt='<p>Size XS</p>', align='center'),
                svg_entry.mock(size='xs', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size S</p>', align='center'),
                svg_entry.mock(size='s', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size M</p>', align='center'),
                svg_entry.mock(size='m', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size L</p>', align='center'),
                svg_entry.mock(size='l', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size X</p>', align='center'),
                svg_entry.mock(size='x', theme=constants.THEME_LIGHT),
                text_entry.mock(txt='<p>Size XL</p>', align='center'),
                svg_entry.mock(size='xl', theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=image_page)
        mocker.menu(image_page, block_menu_id)
        mocker.add_menu(image_page, home_page_menu_id)

        # -------------------------------- TimeLine --------------------------------

        timeline_page = ContentPage(
            title="Timeline",
            slug='timeline',
            body=json.dumps([
                text_entry.mock(txt='<h1>Timeline</h1>', align='center'),
                time_line_entry.mock(),
                time_line_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                time_line_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=timeline_page)
        mocker.menu(timeline_page, block_menu_id)
        mocker.add_menu(timeline_page, home_page_menu_id)

        # -------------------------------- Line Medias --------------------------------

        medias_line_page = ContentPage(
            title="Medias Line",
            slug='medias-line',
            body=json.dumps([
                text_entry.mock(txt='<h1>Medias Line</h1>', align='center'),
                medias_line_entry.mock(2),
                medias_line_entry.mock(),
                medias_line_entry.mock(4),
            ])
        )
        block_page.add_child(instance=medias_line_page)
        mocker.menu(medias_line_page, block_menu_id)
        mocker.add_menu(medias_line_page, home_page_menu_id)

        # -------------------------------- Grid Info --------------------------------

        grid_info_page = ContentPage(
            title="Grid Info",
            slug='grid-info',
            body=json.dumps([
                text_entry.mock(txt='<h1>Grid Info</h1>', align='center'),
                grid_info_entry.mock(),
                grid_info_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                grid_info_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=grid_info_page)
        mocker.menu(grid_info_page, block_menu_id)
        mocker.add_menu(grid_info_page, home_page_menu_id)

        # -------------------------------- Buttons --------------------------------

        buttons_page = ContentPage(
            title="Buttons",
            slug='buttons',
            body=json.dumps([
                text_entry.mock(txt='<h1>Buttons</h1>', align='center'),
                buttons_entry.mock(),
                buttons_entry.mock(align='center', theme=constants.THEME_SPACE_INVERSE),
                buttons_entry.mock(align='right', theme=constants.THEME_LIGHT),

                buttons_entry.mock(btn_one=constants.BUTTON_PRIMARY, btn_two=constants.BUTTON_PRIMARY_FULL),
                buttons_entry.mock(theme=constants.THEME_SPACE_INVERSE, btn_one=constants.BUTTON_PRIMARY,
                                   btn_two=constants.BUTTON_PRIMARY_FULL, align='center'),
                buttons_entry.mock(theme=constants.THEME_LIGHT, btn_one=constants.BUTTON_PRIMARY,
                                   btn_two=constants.BUTTON_PRIMARY_FULL, align='right'),

                buttons_entry.mock(btn_one=constants.BUTTON_TERTIARY, btn_two=constants.BUTTON_TERTIARY_FULL,
                                   theme=constants.THEME_LIGHT),
                buttons_entry.mock(theme=constants.THEME_SPACE_INVERSE, btn_one=constants.BUTTON_TERTIARY,
                                   btn_two=constants.BUTTON_TERTIARY_FULL, align='center'),
                buttons_entry.mock(theme=constants.THEME_LIGHT, btn_one=constants.BUTTON_TERTIARY,
                                   btn_two=constants.BUTTON_TERTIARY_FULL, align='right'),
            ])
        )
        block_page.add_child(instance=buttons_page)
        mocker.menu(buttons_page, block_menu_id)
        mocker.add_menu(buttons_page, home_page_menu_id)

        # -------------------------------- Calendly --------------------------------

        calendly_page = ContentPage(
            title="Calendly",
            slug='calendly',
            body=json.dumps([
                text_entry.mock(txt='<h1>Calendly</h1>', align='center'),
                calendly_entry.mock(),
            ])
        )
        block_page.add_child(instance=calendly_page)
        mocker.menu(calendly_page, block_menu_id)
        mocker.add_menu(calendly_page, home_page_menu_id)

        # -------------------------------- Table --------------------------------

        table_page = ContentPage(
            title="Table",
            slug='table',
            body=json.dumps([
                text_entry.mock(txt='<h1>Tables</h1>', align='center'),
                table_entry.mock(),
                table_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                table_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=table_page)
        mocker.menu(table_page, block_menu_id)
        mocker.add_menu(table_page, home_page_menu_id)

        # -------------------------------- Accordion --------------------------------

        accordion_page = ContentPage(
            title="Accordion",
            slug='accordion',
            body=json.dumps([
                text_entry.mock(txt='<h1>Accordion</h1>', align='center'),
                accordion_entry.mock(),
                accordion_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                accordion_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=accordion_page)
        mocker.menu(accordion_page, block_menu_id)
        mocker.add_menu(accordion_page, home_page_menu_id)

        # -------------------------------- Numbers --------------------------------

        numbers_page = ContentPage(
            title="Numbers",
            slug='numbers',
            body=json.dumps([
                text_entry.mock(txt='<h1>Numbers</h1>', align='center'),
                numbers_entry.mock(),
                numbers_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                numbers_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=numbers_page)
        mocker.menu(numbers_page, block_menu_id)
        mocker.add_menu(numbers_page, home_page_menu_id)

        # -------------------------------- Forms --------------------------------

        forms_page = ContentPage(
            title="Forms",
            slug='forms',
            body=json.dumps([
                text_entry.mock(txt='<h1>Form</h1>', align='center'),
                form_entry.mock(),
                form_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                form_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=forms_page)
        mocker.menu(forms_page, block_menu_id)
        mocker.add_menu(forms_page, home_page_menu_id)

        # -------------------------------- Social Media --------------------------------

        forms_page = ContentPage(
            title="Social Media",
            slug='social-media',
            body=json.dumps([
                text_entry.mock(txt='<h1>Social Media</h1>', align='center'),
                social_links.mock(),
                social_links.mock(theme=constants.THEME_SPACE_INVERSE),
                social_links.mock(theme=constants.THEME_LIGHT),
                social_share.mock(),
                social_share.mock(theme=constants.THEME_SPACE_INVERSE),
                social_share.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=forms_page)
        mocker.menu(forms_page, block_menu_id)
        mocker.add_menu(forms_page, home_page_menu_id)

        # -------------------------------- Gallery --------------------------------

        gallery_page = ContentPage(
            title="Gallery",
            slug='gallery',
            body=json.dumps([
                text_entry.mock(txt='<h1>Gallery</h1>', align='center'),
                gallery_entry.mock(),
                gallery_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                gallery_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=gallery_page)
        mocker.menu(gallery_page, block_menu_id)
        mocker.add_menu(gallery_page, home_page_menu_id)

        # -------------------------------- Stream Content --------------------------------

        stream_content_page = ContentPage(
            title="Stream Content",
            slug='stream-content',
            body=json.dumps([
                text_entry.mock(txt='<h1>Stream Content</h1>', align='center'),
                stream_content_entry.mock(),
                stream_content_entry.mock(theme=constants.THEME_SPACE_INVERSE),
                stream_content_entry.mock(theme=constants.THEME_LIGHT),
            ])
        )
        block_page.add_child(instance=stream_content_page)
        mocker.menu(stream_content_page, block_menu_id)
        mocker.add_menu(stream_content_page, home_page_menu_id)

        # -------------------------------- Settings --------------------------------

        ws_settings = WebspaceSettings.for_site(site)
        ws_settings.brand_name = "SpaceX"
        ws_settings.logo_header_primary = json.dumps([{
            'type': 'svg',
            'value': mocker.file(mocker.SVG_LOGO_SPACE).id
        }])
        ws_settings.logo_header_secondary = json.dumps([{
            'type': 'svg',
            'value': mocker.file(mocker.SVG_LOGO_LIGHT).id
        }])
        ws_settings.favicon = mocker.file(mocker.IMG_ICON_SPACE)
        ws_settings.language = 'fr'
        ws_settings.collect_text = "<p>En poursuivant votre navigation sur ce site, vous acceptez nos CGU ainsi que notre Politique de confidentialité</p>"
        ws_settings.social_share_text = """
        <h2>Partager cette page!</h2>
        <hr>
        <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
            recrutent.</p>
        """
        ws_settings.social_links_text = """
        <h2>Suivez-nous!</h2>
        <hr>
        <p>Chaque semaine dans votre boite mail, un condensé de conseils et de nouvelles entreprises qui
            recrutent.</p>
        """
        ws_settings.summary_text = """
        <h2>Sommaire</h2>
        <hr>
        """
        ws_settings.search_text = """
        <h2>Recherche</h2>
        <hr>
        """
        ws_settings.related_articles_text = """
        <h2>Articles related</h2>
        <hr>
        """

        ws_settings.related_portfolios_text = """
        <h2>Portfolios related</h2>
        <hr>
        """

        ws_settings.newsletter = Mocker.get_form('newsletter', nb_fields=1, head_text=False)

        ws_settings.facebook = mocker.URL_TEST
        ws_settings.instagram = mocker.URL_TEST
        ws_settings.linkedin = mocker.URL_TEST
        ws_settings.twitter = mocker.URL_TEST
        ws_settings.youtube = mocker.URL_TEST
        ws_settings.pinterest = mocker.URL_TEST
        ws_settings.save()

        rss = RSSFeedsSettings.for_site(site)
        rss.feed_app_label = 'cms'
        rss.feed_model_name = 'BlogPage'
        rss.feed_title = 'Change me'
        rss.feed_link = 'https://changeme.com'
        rss.feed_description = 'Change me'
        rss.feed_author_email = 'change@me.me'
        rss.feed_author_link = 'https://changeme.com'
        rss.feed_item_description_field = 'intro'
        rss.feed_item_content_field = 'body'
        rss.feed_image_in_content = True
        rss.feed_item_date_field = 'date'
        rss.is_feed_item_date_field_datetime = True
        rss.save()

    def icons(self):
        keys = [
            "user",
            "angle",
            "cross",
            "cross_red",
            "email",
            "facebook",
            "instagram",
            "linkedin",
            "twitter",
            "youtube",
            "pinterest",
            "info",
            "right",
            "left",
            "map_marker",
            "success",
            "pen",
            "phone",
            "help",
            "search",
            "tick",
            "time",
            "user",
            "accordion",
            "fr",
            "en",
            "star_enable",
            "star_disable",
        ]
        for key in keys:
            ico, created = IconSnippet.objects.get_or_create(
                key=key
            )
            if created:
                ico.save()

    def docs(self):
        MyDocument.objects.all().delete()
        doc_path = 'CHANGE_ME/cms/management/commands/files/documents'
        doc_files = [f for f in listdir(doc_path) if isfile(join(doc_path, f))]
        for doc_name in doc_files:
            file_title = doc_name.replace('.svg', '').replace('-', ' ').replace('_', ' ').title()
            file = ImageFile(
                open(doc_path + '/' + doc_name, "rb"),
                name=file_title + '.svg'
            )
            try:
                document = MyDocument.objects.get(title=file_title)
            except MyDocument.DoesNotExist:
                document = MyDocument(
                    title=file_title,
                    file=file
                )
                document.save()

            if 'icon_' in doc_name:
                doc_name_sp = doc_name.split('_')
                key_icon = doc_name_sp[1]
                theme = doc_name_sp[2]
                key_icon = key_icon.replace('-', '_')
                try:
                    icon = IconSnippet.objects.get(key=key_icon)
                    if theme == 'light.svg':
                        icon.light = document
                        icon.save()
                    if theme == 'space.svg':
                        icon.space = document
                        icon.save()
                except IconSnippet.DoesNotExist:
                    print("Error key icon does not exist")
                    import pdb
                    pdb.set_trace()

    def imgs(self):
        Image.objects.all().delete()
        doc_path = 'CHANGE_ME/cms/management/commands/files/images'
        doc_files = [f for f in listdir(doc_path) if isfile(join(doc_path, f))]
        for doc_name in doc_files:
            file_title = doc_name.replace('.png', '').replace('-', ' ').replace('_', ' ').title()
            file = ImageFile(
                open(doc_path + '/' + doc_name, "rb"),
                name=file_title + '.png'
            )
            try:
                document = Image.objects.get(title=file_title)
            except Image.DoesNotExist:
                document = Image(
                    title=file_title,
                    file=file
                )
                document.save()



from wagtail.core.signals import page_published, page_unpublished


def handle_publish(sender, instance, **kwargs):
    from webspace.bakery.models import VersionBuild
    from .abstract import WagtailPageBakeryModel
    if isinstance(instance, WagtailPageBakeryModel):
        instance.build()
        vb = VersionBuild.get()
        vb.minor()


def handle_unpublish(sender, instance, **kwargs):
    #  from .abstract import WagtailPageBakeryModel
    #  if isinstance(instance, WagtailPageBakeryModel):
    #    instance.unbuild()
    pass


def register_signal_handlers():
    page_published.connect(
        handle_publish, dispatch_uid='wagtailbakery_page_published')
    page_unpublished.connect(
        handle_unpublish, dispatch_uid='wagtailbakery_page_unpublished')



from django.http import HttpResponse
from django.shortcuts import render
from django.template.loader import render_to_string

from webspace.loader import get_model

IconSnippet = get_model('cms', 'IconSnippet')


def robots(request):
    return HttpResponse(
        render_to_string('robots.txt', {'request': request}),
        content_type='text/plain'
    )


def error_404(request, exception=None):
    context = {}
    context['icons'] = IconSnippet.get_context()
    return render(request, 'cms/pages/404.html', context, status=404)


def worker(request, version):
    from wagtail.contrib.sitemaps.sitemap_generator import Sitemap
    return HttpResponse(render_to_string(
        'worker.js',
        {
            'request': request,
            'pages': Sitemap(request),
            'version': version
        }),
        content_type='application/javascript'
    )



# Env
import os
import sys
import six

# Files
import gzip
import mimetypes
from webspace.bakery import DEFAULT_GZIP_CONTENT_TYPES

# Filesystem
from fs import path
from fs import copy
from django.utils.encoding import smart_text

# Pooling
import multiprocessing
from multiprocessing.pool import ThreadPool

# Django tricks
from django.apps import apps
from django.conf import settings
from django.urls import get_callable
from django.core.management.base import BaseCommand, CommandError

from webspace.bakery.models import VersionBuild


class Command(BaseCommand):
    help = 'Bake out a site as flat files in the build directory'
    build_unconfig_msg = "Build directory unconfigured. Set BUILD_DIR in settings.py or provide it with --build-dir"
    views_unconfig_msg = "Bakery views unconfigured. Set BAKERY_VIEWS in settings.py or provide a list as arguments."
    # regex to match against for gzipping. CSS, JS, JSON, HTML, etc.
    gzip_file_match = getattr(
        settings,
        'GZIP_CONTENT_TYPES',
        DEFAULT_GZIP_CONTENT_TYPES
    )

    def handle(self, *args, **options):
        self.stdout.write(self.style.SUCCESS('Start Bakery build'))
        vb = VersionBuild.get()
        vb.minor()
        self.set_options(*args, **options)
        self.init_build_dir()
        self.build_views()
        self.stdout.write(self.style.SUCCESS('Build finished'))

    def set_options(self, *args, **options):
        self.verbosity = int(options.get('verbosity', 1))
        if not hasattr(settings, 'BUILD_DIR'):
            raise CommandError(self.build_unconfig_msg)
        self.build_dir = settings.BUILD_DIR
        self.build_dir = smart_text(self.build_dir)
        self.static_root = smart_text(settings.STATIC_ROOT)
        self.media_root = smart_text(settings.MEDIA_ROOT)
        self.app = apps.get_app_config("bakery")
        self.fs = self.app.filesystem
        self.fs_name = self.app.filesystem_name
        if not self.fs.exists(self.build_dir):
            self.fs.makedirs(self.build_dir)
        if not hasattr(settings, 'BAKERY_VIEWS'):
            raise CommandError(self.views_unconfig_msg)
        self.view_list = settings.BAKERY_VIEWS

    def init_build_dir(self):
        self.stdout.write(self.style.SUCCESS("Initializing %s" % self.build_dir))
        if self.fs.exists(self.build_dir):
            pass
            #   self.fs.removetree(self.build_dir)
        else:
            self.fs.makedirs(self.build_dir)

    def get_view_instance(self, view):
        return view()

    def build_views(self):
        for view_str in self.view_list:
            self.stdout.write("Building %s" % view_str)
            view = get_callable(view_str)
            self.get_view_instance(view).build_method()

    def copytree_and_gzip(self, source_dir, target_dir):
        build_list = []
        for (dirpath, dirnames, filenames) in os.walk(source_dir):
            for f in filenames:
                source_path = os.path.join(dirpath, f)
                rel_path = os.path.relpath(dirpath, source_dir)
                target_path = os.path.join(target_dir, rel_path, f)
                build_list.append((source_path, target_path))
        if not getattr(self, 'pooling', False):
            [self.copyfile_and_gzip(*u) for u in build_list]
        else:
            cpu_count = multiprocessing.cpu_count()
            pool = ThreadPool(processes=cpu_count)
            pool.map(self.pooled_copyfile_and_gzip, build_list)

    def pooled_copyfile_and_gzip(self, payload):
        self.copyfile_and_gzip(*payload)

    def copyfile_and_gzip(self, source_path, target_path):
        target_dir = path.dirname(target_path)
        if not self.fs.exists(target_dir):
            try:
                self.fs.makedirs(target_dir)
            except OSError:
                pass
        guess = mimetypes.guess_type(source_path)
        content_type = guess[0]
        encoding = guess[1]

        if content_type not in self.gzip_file_match:
            copy.copy_file("osfs:///", smart_text(source_path), self.fs, smart_text(target_path))
        elif encoding == 'gzip':
            copy.copy_file("osfs:///", smart_text(source_path), self.fs, smart_text(target_path))
        else:
            with open(source_path, 'rb') as source_file:
                data_buffer = six.BytesIO()
                kwargs = dict(
                    filename=path.basename(target_path),
                    mode='wb',
                    fileobj=data_buffer
                )
                if float(sys.version[:3]) >= 2.7:
                    kwargs['mtime'] = 0
                with gzip.GzipFile(**kwargs) as f:
                    f.write(six.binary_type(source_file.read()))
                with self.fs.open(smart_text(target_path), 'wb') as outfile:
                    outfile.write(data_buffer.getvalue())
                    outfile.close()



# Generated by Django 3.0.7 on 2020-07-22 17:40

from django.db import migrations
import modelcluster.contrib.taggit


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('cms', '0012_auto_20200722_1734'),
    ]

    operations = [
        migrations.AlterField(
            model_name='portfoliopage',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='cms.PortfolioPageTag', to='taggit.Tag', verbose_name='Tags'),
        ),
    ]



from django.conf import settings


class ConfigMiddleware(object):

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        setattr(request, 'version', settings.VERSION)
        setattr(request, 'version_webspace', settings.VERSION_WEBSPACE)
        response = self.get_response(request)
        return response



# Generated by Django 3.0.9 on 2020-08-25 15:34

from django.db import migrations, models
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0019_auto_20200812_1236'),
    ]

    operations = [
        migrations.AddField(
            model_name='webspacesettings',
            name='primary_inverse_bg_color',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='primary_inverse_color_uks',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='secondary_color',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='secondary_color_uks',
            field=models.CharField(blank=True, default='', max_length=20),
        ),
        migrations.AlterField(
            model_name='genericpage',
            name='schemas',
            field=wagtail.core.fields.StreamField([('how_to', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.CharBlock(required=True)), ('description', wagtail.core.blocks.CharBlock(required=True)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=True)), ('total_time', wagtail.core.blocks.CharBlock(required=True)), ('tool', wagtail.core.blocks.CharBlock(required=True)), ('supply', wagtail.core.blocks.CharBlock(required=True)), ('step', wagtail.core.blocks.StreamBlock([('step', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(required=True)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image 500x500', required=False)), ('name', wagtail.core.blocks.CharBlock(required=True)), ('url', wagtail.core.blocks.URLBlock(required=False))]))]))])), ('faq_page', wagtail.core.blocks.StructBlock([('questions', wagtail.core.blocks.StreamBlock([('questions', wagtail.core.blocks.StructBlock([('question', wagtail.core.blocks.CharBlock(required=True)), ('answer', wagtail.core.blocks.CharBlock(required=True))]))]))]))], blank=True),
        ),
    ]



from django.db import models
from wagtail.snippets.edit_handlers import SnippetChooserPanel

from webspace.bakery.abstract import WagtailPageBakeryModel
from webspace.cms.amp.mixins import AmpMixin
from webspace.loader import get_model
from webspace.cms.forms.abstract import FormMixin

GenericPage = get_model('cms', 'GenericPage')
Form = get_model('cms', 'Form')


class AContactPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
    form = models.ForeignKey(
        Form,
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name="Formulaire",
    )

    content_panels = [
        SnippetChooserPanel('form')
    ] + GenericPage.content_panels

    class Meta:
        abstract = True
        app_label = 'cms'



# Generated by Django 3.0.7 on 2020-07-03 11:28

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('cms', '0003_auto_20200702_1538'),
    ]

    operations = [
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('help_text', models.CharField(blank=True, default='', max_length=100)),
                ('first_name', models.CharField(blank=True, default='', max_length=200)),
                ('last_name', models.CharField(blank=True, default='', max_length=200)),
                ('title', wagtail.core.fields.RichTextField(blank=True, default='', help_text='Titre')),
                ('description', wagtail.core.fields.RichTextField(blank=True, default='', help_text='Bio')),
                ('email_contact', models.CharField(blank=True, default='', max_length=200)),
                ('facebook', models.URLField(blank=True, help_text='Facebook page URL')),
                ('instagram', models.URLField(blank=True, help_text='Instagram page URL')),
                ('linkedin', models.URLField(blank=True, help_text='Linkedin page URL')),
                ('twitter', models.URLField(blank=True, help_text='Twitter page URL')),
                ('pinterest', models.URLField(blank=True, help_text='Pinterest page URL')),
                ('youtube', models.URLField(blank=True, help_text='Youtube page URL')),
                ('calendly', models.URLField(blank=True, help_text='Calendly URL')),
                ('image_miniature', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image Miniature')),
                ('image_presentation', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image Presentation')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import EntryBlock


class ArticlesEntry(EntryBlock):
    articles = blocks.StreamBlock(
        [
            ('article', blocks.PageChooserBlock(required=False, target_model='cms.BlogPage')),
        ],
        min_num=1
    )

    class Meta:
        template = '%s/entries/articles.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Articles"



from django.urls import include, path, reverse
from wagtail.admin.menu import MenuItem
from wagtail.core import hooks

from webspace.bakery import urls as urls_bakery


class BakeryItem(MenuItem):
    """
    Registers wagtail-cache in wagtail admin for superusers.
    """

    def is_shown(self, request):
        return request.user.is_superuser


@hooks.register('register_admin_urls')
def register_admin_urls():
    """
    Registers wagtail-cache urls in the wagtail admin.
    """
    return [
        path('bakery/', include((urls_bakery, 'bakery'), namespace='bakery')),
    ]


@hooks.register('register_settings_menu_item')
def register_cache_menu():
    """
    Registers bakery settings panel in the wagtail admin.
    """
    return BakeryItem(
        'Bakery',
        reverse('bakery:index'),
        classnames='icon icon-cog')



#!/usr/bin/env python
import os
import sys
from setuptools import find_packages, setup
import json


PROJECT_DIR = os.path.dirname(__file__)

sys.path.append(os.path.join(PROJECT_DIR, 'src'))

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('./src/package.json') as package:
    data = json.load(package)
    version = data['version']


setup(
    name='webspace',
    version=version,
    url='https://github.com/Aleksi44/webspace',
    author="Alexis Le Baron",
    author_email="alexis@stationspatiale.com",
    description="Utils for web",
    long_description=long_description,
    keywords="web",
    license='BSD',
    install_requires=[
        'django==3.0.9',
        'wagtail==2.10',
        'django_storages==1.9.1',
        'django-user-agents==0.3.2',
        'psycopg2-binary',
        'lxml==4.2.1',
        'readtime==1.1.1',
        'fs==2.4.11',
        'django-social-share==1.4.0',
        'django-environ==0.4.5',
        'boto3==1.6.19',
        'uwsgi==2.0.18',
        'django-wagtail-feeds==0.1.0',
        'ipython==5.3.0',
        'django-rosetta==0.9.4',
        'sentry-sdk==0.16.5',
        'celery==4.4.6',
        'redis==3.5.3',
        'django-csp==3.6'
    ],
    platforms=['linux'],
    package_dir={'': 'src'},
    packages=find_packages('src'),
    include_package_data=True,
)



# Generated by Django 3.0.7 on 2020-07-29 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bakery', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='VersionBuild',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(blank=True, default=None, max_length=100, null=True)),
                ('total_build', models.IntegerField(default=0)),
            ],
        ),
    ]



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    SvgBlock, \
    ImageBlock, \
    EntryBlock


class SvgInfo(SvgBlock):
    page = blocks.PageChooserBlock(required=False)
    link = blocks.URLBlock(required=False)
    title = blocks.CharBlock()
    text_hover = TextBlock()


class ImageInfo(ImageBlock):
    page = blocks.PageChooserBlock(required=False)
    link = blocks.URLBlock(required=False)
    title = blocks.CharBlock()
    text_hover = TextBlock()


class GridInfoEntry(EntryBlock):
    infos = blocks.StreamBlock(
        [
            ('svg_info', SvgInfo()),
            ('image_info', ImageInfo()),
        ],
        min_num=1
    )

    def mock(self, *args, **kwargs):
        if 'theme' in kwargs:
            file = self.SVG_ICON_LIGHT \
                if kwargs['theme'] == constants.THEME_LIGHT else self.SVG_ICON_SPACE
        else:
            file = self.SVG_ICON_SPACE
        info = {
            'type': 'svg_info',
            'value': {
                'file': self.file(file).id,
                'title': "Lorem ipsum",
                'text_hover': {
                    'value': "<h3>lorem ipsum dolor sit amet consectetur adipisicing elit sed do eiusmod</h3>"
                }
            }
        }
        self.mock_data.update({
            'type': 'grid_info',
            'value': {
                'infos': [
                    info,
                    info,
                    info,
                    info,
                    info,
                    info,
                ]
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/grid_info.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Grid Info"



from wagtail.core import blocks

from webspace.cms import constants
from webspace.cms.blocks.common import \
    TextBlock, \
    EntryBlock


class ClassicNumbersItem(blocks.StructBlock):
    number = blocks.IntegerBlock(required=True)
    unit = blocks.CharBlock(required=False, help_text='unité de mesure')
    content = TextBlock(label="Content")


class NumbersEntry(EntryBlock):
    items = blocks.StreamBlock([
        ('classic', ClassicNumbersItem()),
    ], min_num=1)

    def mock(self, *args, **kwargs):
        classic = {
            'type': 'classic',
            'value': {
                'number': 90,
                'unit': '%',
                'content': {'value': self.p},
            }
        }

        self.mock_data.update({
            'type': 'numbers',
            'value': {
                'items': [classic, classic, classic, classic]
            }
        })
        return super().mock(*args, **kwargs)

    class Meta:
        template = '%s/entries/numbers.html' % constants.BLOCK_TEMPLATES_PATH
        label = "Numbers"



from wagtail.core import blocks
from wagtail.images.blocks import ImageChooserBlock

from .. import constants


class HowToStep(blocks.StructBlock):
    text = blocks.CharBlock(required=True)
    image = ImageChooserBlock(label="Image 500x500", required=False)
    name = blocks.CharBlock(required=True)
    url = blocks.URLBlock(required=False)


class HowTo(blocks.StructBlock):
    name = blocks.CharBlock(required=True)
    description = blocks.CharBlock(required=True)
    image = ImageChooserBlock(label="Image 500x500", required=True)
    total_time = blocks.CharBlock(required=True)
    tool = blocks.CharBlock(required=True)
    supply = blocks.CharBlock(required=True)

    step = blocks.StreamBlock(
        [
            ('step', HowToStep()),
        ],
    )

    class Meta:
        label = "Schema HowTo"
        template = '%s/schemas/how_to.html' % constants.BLOCK_TEMPLATES_PATH


class Question(blocks.StructBlock):
    question = blocks.CharBlock(required=True)
    answer = blocks.CharBlock(required=True)


class FAQPage(blocks.StructBlock):
    questions = blocks.StreamBlock(
        [
            ('questions', Question()),
        ],
    )

    class Meta:
        label = "Schema FAQPage"
        template = '%s/schemas/faq_page.html' % constants.BLOCK_TEMPLATES_PATH



from django.db import models
from modelcluster.fields import ParentalKey
from modelcluster.models import ClusterableModel
from wagtail.admin.edit_handlers import (
    MultiFieldPanel,
    InlinePanel,
    FieldPanel,
    PageChooserPanel,
)
from wagtail.core.models import Orderable


class AMenuItem(Orderable):
    link_title = models.CharField(
        blank=True,
        null=True,
        max_length=50
    )
    link_url = models.CharField(
        max_length=500,
        blank=True
    )
    link_page = models.ForeignKey(
        "wagtailcore.Page",
        null=True,
        blank=True,
        related_name="+",
        on_delete=models.CASCADE,
    )
    open_in_new_tab = models.BooleanField(default=False, blank=True)
    menu = ParentalKey("Menu", related_name="menu_items")

    panels = [
        FieldPanel("link_title"),
        FieldPanel("link_url"),
        PageChooserPanel("link_page"),
        FieldPanel("open_in_new_tab"),
    ]

    @property
    def link(self):
        if self.link_page:
            return self.link_page.url
        elif self.link_url:
            return self.link_url
        return '#'

    @property
    def title(self):
        if self.link_page and not self.link_title:
            return self.link_page.title
        elif self.link_title:
            return self.link_title
        return 'Missing Title'

    class Meta:
        verbose_name = "Icon"
        abstract = True
        app_label = 'cms'


class AMenu(ClusterableModel):
    help_text = models.CharField(max_length=100, default='', blank=True)
    title = models.CharField(max_length=100)

    panels = [
        MultiFieldPanel([
            FieldPanel("help_text"),
            FieldPanel("title"),
        ], heading="Menu"),
        InlinePanel("menu_items", label="Menu Items")
    ]

    def __str__(self):
        return self.help_text

    class Meta:
        abstract = True
        app_label = 'cms'



from django.conf import settings
from django.conf.urls import include, url
from django.contrib import admin
from django.conf.urls.static import static
from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtail_urls
from rosetta import urls as rosetta_urls
from wagtail.contrib.sitemaps.views import sitemap
from wagtail_feeds.feeds import BasicFeed, ExtendedFeed
from wagtail.core import views

from .views import robots, error_404, worker
from .cms.amp import urls as wagtail_amp_urls

views.serve.csrf_exempt = True

urlpatterns = [
    url(r'^robots\.txt$', robots),
    url(r'^404$', error_404),
    url(r'^sitemap\.xml$', sitemap),
    url(r'^worker(?P<version>.+).js$', worker),
    url(r'^admin_W3cJ32mq63V45CLvmjNbsqSJ32mq63V45CL/', admin.site.urls),
    url(r'^rosetta_WoQtYMRmgLV9iId6VEfAn1VxpH7aoOUeg/', include(rosetta_urls)),
    url(r'^wagtail_WSQtYMxmgLV9iIn6VE3An1VxpH9aoOUeg/', include(wagtailadmin_urls)),
    url(r"^amp/", include(wagtail_amp_urls)),
    url(r"^", include(wagtail_urls)),
    url(r'^articles/rss/basic$', BasicFeed(), name='basic_feed'),
    url(r'^articles/rss/extended$', ExtendedFeed(), name='extended_feed'),
] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)



import fs
from django.apps import AppConfig
from webspace.bakery.signal_handlers import register_signal_handlers


class BakeryConfig(AppConfig):
    name = 'webspace.bakery'
    label = 'bakery'
    verbose_name = 'bakery'
    filesystem_name = "osfs:///"
    filesystem = fs.open_fs(filesystem_name)

    def ready(self):
        register_signal_handlers()
